from rdflib.namespace import DefinedNamespace, Namespace
from rdflib.term import URIRef


class QUDT_UNIT(DefinedNamespace):
    # Generated with None version 0.8.0
    _fail = True
    MilliGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-K")
    OZ_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ-PER-HR")
    MilliK_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliK-PER-BAR")
    PER_MOL = URIRef("http://qudt.org/vocab/unit/PER-MOL")
    ExaJ = URIRef("http://qudt.org/vocab/unit/ExaJ")
    GM_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/GM-PER-DEG_C")
    KiloCAL_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-HR")
    PER_J_M3 = URIRef("http://qudt.org/vocab/unit/PER-J-M3")
    ERG_CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2-PER-GM")
    PINT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-DAY")
    TeraV_A_Reactive = URIRef("http://qudt.org/vocab/unit/TeraV-A_Reactive")
    LB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT")
    WB_PER_MilliM = URIRef("http://qudt.org/vocab/unit/WB-PER-MilliM")
    EUR_PER_W_SEC = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-SEC")
    MilliPA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-K")
    YoctoC = URIRef("http://qudt.org/vocab/unit/YoctoC")
    KiloGM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM")
    GigaBasePair = URIRef("http://qudt.org/vocab/unit/GigaBasePair")
    MegaBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaBQ-PER-KiloGM")
    KiloCAL_TH = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH")
    KiloGM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR")
    MicroT = URIRef("http://qudt.org/vocab/unit/MicroT")
    WB = URIRef("http://qudt.org/vocab/unit/WB")
    BTU_TH_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB")
    J_PER_GM = URIRef("http://qudt.org/vocab/unit/J-PER-GM")
    OZ_F = URIRef("http://qudt.org/vocab/unit/OZ_F")
    TON_SHORT_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-PSI")
    PERCENT_PER_DEG = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG")
    PINT_UK = URIRef("http://qudt.org/vocab/unit/PINT_UK")
    HR = URIRef("http://qudt.org/vocab/unit/HR")
    MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/MOL-DEG_C")
    LB_PER_FT3 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3")
    ANGSTROM = URIRef("http://qudt.org/vocab/unit/ANGSTROM")
    KiloGM_PER_L_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-K")
    MegaV = URIRef("http://qudt.org/vocab/unit/MegaV")
    PPB = URIRef("http://qudt.org/vocab/unit/PPB")
    MOL_PER_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-HR")
    CAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-MIN")
    KAT = URIRef("http://qudt.org/vocab/unit/KAT")
    KiloN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M2")
    U = URIRef("http://qudt.org/vocab/unit/U")
    HectoBAR = URIRef("http://qudt.org/vocab/unit/HectoBAR")
    KiloM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC-BAR")
    M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC")
    MegaPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-M3-PER-SEC")
    HectoPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-L-PER-SEC")
    M2_HZ4 = URIRef("http://qudt.org/vocab/unit/M2-HZ4")
    DecaGM = URIRef("http://qudt.org/vocab/unit/DecaGM")
    TON_SHORT_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR")
    BTU_TH_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_F")
    MilliGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2")
    GM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L2")
    MilliOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-M")
    TONNE = URIRef("http://qudt.org/vocab/unit/TONNE")
    FemtoV = URIRef("http://qudt.org/vocab/unit/FemtoV")
    LB_IN2 = URIRef("http://qudt.org/vocab/unit/LB-IN2")
    C4_M4_PER_J3 = URIRef("http://qudt.org/vocab/unit/C4-M4-PER-J3")
    M3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC2")
    GM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL")
    NanoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-KiloGM")
    C_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM3")
    GRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/GRAY-PER-HR")
    NanoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoW-PER-M2")
    CentiM_HG = URIRef("http://qudt.org/vocab/unit/CentiM_HG")
    OZ_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_UK")
    LB_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_US")
    BU_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-HR")
    GM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciL")
    N_M = URIRef("http://qudt.org/vocab/unit/N-M")
    Gamma = URIRef("http://qudt.org/vocab/unit/Gamma")
    KiloSEC = URIRef("http://qudt.org/vocab/unit/KiloSEC")
    MegaGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-HA")
    W_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-SR")
    V_Ab_SEC = URIRef("http://qudt.org/vocab/unit/V_Ab-SEC")
    KiloM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC")
    MegaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M3")
    EV_PER_M = URIRef("http://qudt.org/vocab/unit/EV-PER-M")
    HZ_PER_K = URIRef("http://qudt.org/vocab/unit/HZ-PER-K")
    LB_MIN_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-FT3")
    V_PER_M = URIRef("http://qudt.org/vocab/unit/V-PER-M")
    PER_PA = URIRef("http://qudt.org/vocab/unit/PER-PA")
    C_Stat = URIRef("http://qudt.org/vocab/unit/C_Stat")
    MilliM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC")
    KiloJ_PER_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-K")
    DeciTONNE = URIRef("http://qudt.org/vocab/unit/DeciTONNE")
    GRAIN_PER_GAL = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL")
    RPK = URIRef("http://qudt.org/vocab/unit/RPK")
    PERCENT_PER_HectoBAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoBAR")
    HART = URIRef("http://qudt.org/vocab/unit/HART")
    J = URIRef("http://qudt.org/vocab/unit/J")
    EV_PER_K = URIRef("http://qudt.org/vocab/unit/EV-PER-K")
    GM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-BAR")
    PT = URIRef("http://qudt.org/vocab/unit/PT")
    LB_IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN-PER-SEC")
    KiloCAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-GM-K")
    LB_HR_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_UK")
    KiloBTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH-PER-HR")
    MegaN = URIRef("http://qudt.org/vocab/unit/MegaN")
    MilliPA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC-PER-BAR")
    SV_PER_MIN = URIRef("http://qudt.org/vocab/unit/SV-PER-MIN")
    NanoW = URIRef("http://qudt.org/vocab/unit/NanoW")
    N_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM2")
    KiloGM_PER_HA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HA")
    UnitPole = URIRef("http://qudt.org/vocab/unit/UnitPole")
    LM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LM-PER-FT2")
    W_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M3")
    GM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3")
    KiloGM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-K")
    MegaA_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaA-PER-M2")
    CD = URIRef("http://qudt.org/vocab/unit/CD")
    MicroGM = URIRef("http://qudt.org/vocab/unit/MicroGM")
    FT3 = URIRef("http://qudt.org/vocab/unit/FT3")
    MicroGM_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L-HR")
    M3_PER_HR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR")
    MilliBQ = URIRef("http://qudt.org/vocab/unit/MilliBQ")
    DEG_C_PER_M = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-M")
    PK_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-HR")
    NUM_PER_CentiM_KiloYR = URIRef("http://qudt.org/vocab/unit/NUM-PER-CentiM-KiloYR")
    PINT_US = URIRef("http://qudt.org/vocab/unit/PINT_US")
    TON_LONG = URIRef("http://qudt.org/vocab/unit/TON_LONG")
    K_PER_K = URIRef("http://qudt.org/vocab/unit/K-PER-K")
    MegaPA_M0dot5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0dot5")
    OZ_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-FT3")
    DEG_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG-PER-MIN")
    V = URIRef("http://qudt.org/vocab/unit/V")
    GM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloM")
    KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A-HR")
    M2_PER_W = URIRef("http://qudt.org/vocab/unit/M2-PER-W")
    MilliM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-BAR")
    MOL_PER_TONNE = URIRef("http://qudt.org/vocab/unit/MOL-PER-TONNE")
    OHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-PER-KiloM")
    PINT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-DAY")
    FARAD_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/FARAD_Ab-PER-CentiM")
    C_PER_M2 = URIRef("http://qudt.org/vocab/unit/C-PER-M2")
    L_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-K")
    MilliOHM = URIRef("http://qudt.org/vocab/unit/MilliOHM")
    BTU_IT_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR")
    DEG_C_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-HR")
    ARCMIN = URIRef("http://qudt.org/vocab/unit/ARCMIN")
    MilliL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-KiloGM")
    PER_TON = URIRef("http://qudt.org/vocab/unit/PER-TON")
    ST = URIRef("http://qudt.org/vocab/unit/ST")
    MicroS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MicroS-PER-CentiM")
    NanoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/NanoFARAD-PER-M")
    PER_MILLE_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PSI")
    CentiM3_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-CentiM3")
    PicoV = URIRef("http://qudt.org/vocab/unit/PicoV")
    DWT = URIRef("http://qudt.org/vocab/unit/DWT")
    BQ_PER_M2 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M2")
    KiloV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-HR")
    KiloCAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-SEC")
    PERCENT_SEC_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-FT3")
    MegaPA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaPA-L-PER-SEC")
    FT_PDL = URIRef("http://qudt.org/vocab/unit/FT-PDL")
    LM = URIRef("http://qudt.org/vocab/unit/LM")
    NanoGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DeciL")
    KiloV_PER_M = URIRef("http://qudt.org/vocab/unit/KiloV-PER-M")
    LB_HR_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-YD3")
    FM = URIRef("http://qudt.org/vocab/unit/FM")
    K_PER_W = URIRef("http://qudt.org/vocab/unit/K-PER-W")
    IU_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliGM")
    UNITLESS = URIRef("http://qudt.org/vocab/unit/UNITLESS")
    GigaPA = URIRef("http://qudt.org/vocab/unit/GigaPA")
    DeciL = URIRef("http://qudt.org/vocab/unit/DeciL")
    HectoPA_PER_K = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-K")
    PDL_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-FT2")
    LB_SEC_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK2")
    KiloGM_PER_M_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC2")
    LB = URIRef("http://qudt.org/vocab/unit/LB")
    MilliA_PER_K = URIRef("http://qudt.org/vocab/unit/MilliA-PER-K")
    IU_PER_L = URIRef("http://qudt.org/vocab/unit/IU-PER-L")
    MilliW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2")
    OZ_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-FT3")
    REV_PER_SEC = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC")
    TON_Assay = URIRef("http://qudt.org/vocab/unit/TON_Assay")
    MilliGM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L2")
    LB_F = URIRef("http://qudt.org/vocab/unit/LB_F")
    BTU_IT_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_F")
    KiloJ_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM-K")
    MegaL = URIRef("http://qudt.org/vocab/unit/MegaL")
    PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PER-CentiM3")
    KiloTON_Metric = URIRef("http://qudt.org/vocab/unit/KiloTON_Metric")
    MilliN_PER_M = URIRef("http://qudt.org/vocab/unit/MilliN-PER-M")
    GigaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-M")
    DEG_C_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-MIN")
    MilliL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-MIN")
    M_PER_MIN = URIRef("http://qudt.org/vocab/unit/M-PER-MIN")
    SR = URIRef("http://qudt.org/vocab/unit/SR")
    GM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-CentiM-PER-SEC")
    PER_MilliL = URIRef("http://qudt.org/vocab/unit/PER-MilliL")
    M3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-K")
    PA_PER_K = URIRef("http://qudt.org/vocab/unit/PA-PER-K")
    KiloJ_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MOL")
    LB_PER_FT_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-HR")
    J_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-GM-DEG_C")
    GigaBYTE = URIRef("http://qudt.org/vocab/unit/GigaBYTE")
    MilliJ = URIRef("http://qudt.org/vocab/unit/MilliJ")
    TeraJ = URIRef("http://qudt.org/vocab/unit/TeraJ")
    SolarMass = URIRef("http://qudt.org/vocab/unit/SolarMass")
    QT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_US-PER-MIN")
    PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2")
    KiloLB_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloLB-PER-HR")
    IN_H2O = URIRef("http://qudt.org/vocab/unit/IN_H2O")
    OZ_VOL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-MIN")
    TON_Metric_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-K")
    DYN_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM2")
    MilliL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN")
    PA_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M3")
    BBL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-DAY")
    MilliS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MilliS-PER-CentiM")
    KiloMOL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-HR")
    C_M2_PER_V = URIRef("http://qudt.org/vocab/unit/C-M2-PER-V")
    PIXEL = URIRef("http://qudt.org/vocab/unit/PIXEL")
    E_h = URIRef("http://qudt.org/vocab/unit/E_h")
    SEC_PER_RAD_M3 = URIRef("http://qudt.org/vocab/unit/SEC-PER-RAD-M3")
    POND = URIRef("http://qudt.org/vocab/unit/POND")
    OHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/OHM-PER-BAR")
    CentiM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC")
    NanoM2 = URIRef("http://qudt.org/vocab/unit/NanoM2")
    TON_F_US = URIRef("http://qudt.org/vocab/unit/TON_F_US")
    MegaYR = URIRef("http://qudt.org/vocab/unit/MegaYR")
    GM_PER_M2 = URIRef("http://qudt.org/vocab/unit/GM-PER-M2")
    MicroMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MicroMOL-DAY")
    MilliDEG_C = URIRef("http://qudt.org/vocab/unit/MilliDEG_C")
    MilliC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M2")
    DEATHS_PER_MegaINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-MegaINDIV-YR")
    LB_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN2")
    N_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-PER-M2")
    LB_PER_IN3 = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3")
    GAL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-DAY")
    LB_PER_YD = URIRef("http://qudt.org/vocab/unit/LB-PER-YD")
    H_PER_OHM = URIRef("http://qudt.org/vocab/unit/H-PER-OHM")
    FT_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-PSI")
    MilliL_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-BAR")
    PSI_YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-YD3-PER-SEC")
    M_PER_HR = URIRef("http://qudt.org/vocab/unit/M-PER-HR")
    MicroA_PER_K = URIRef("http://qudt.org/vocab/unit/MicroA-PER-K")
    MegaBYTE = URIRef("http://qudt.org/vocab/unit/MegaBYTE")
    L_PER_MIN = URIRef("http://qudt.org/vocab/unit/L-PER-MIN")
    DEG_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC")
    KiloHZ = URIRef("http://qudt.org/vocab/unit/KiloHZ")
    MilliM_PER_YR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-YR")
    CI_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CI-PER-KiloGM")
    PER_BAR = URIRef("http://qudt.org/vocab/unit/PER-BAR")
    PER_M3 = URIRef("http://qudt.org/vocab/unit/PER-M3")
    DRAM_US = URIRef("http://qudt.org/vocab/unit/DRAM_US")
    MilliBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-L")
    GigaFLOPS = URIRef("http://qudt.org/vocab/unit/GigaFLOPS")
    FT_LB_F_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-HR")
    LB_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-YD3")
    SHANNON_PER_SEC = URIRef("http://qudt.org/vocab/unit/SHANNON-PER-SEC")
    LB_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN6")
    PERCENT_MIN_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-L")
    MilliC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliC-PER-KiloGM")
    A = URIRef("http://qudt.org/vocab/unit/A")
    MilliTORR = URIRef("http://qudt.org/vocab/unit/MilliTORR")
    FemtoM = URIRef("http://qudt.org/vocab/unit/FemtoM")
    MO = URIRef("http://qudt.org/vocab/unit/MO")
    PER_CentiM = URIRef("http://qudt.org/vocab/unit/PER-CentiM")
    GM_Carbon_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Carbon-PER-M2-DAY")
    A_PER_M = URIRef("http://qudt.org/vocab/unit/A-PER-M")
    GM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-BAR")
    KiloPA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-M")
    BARN_PER_SR_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR-EV")
    HP = URIRef("http://qudt.org/vocab/unit/HP")
    PicoW = URIRef("http://qudt.org/vocab/unit/PicoW")
    MilliGM_MIN_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L2")
    ARCSEC = URIRef("http://qudt.org/vocab/unit/ARCSEC")
    A_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-PER-CentiM2")
    MegaC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaC-PER-M2")
    ExbiBYTE = URIRef("http://qudt.org/vocab/unit/ExbiBYTE")
    L_PER_K = URIRef("http://qudt.org/vocab/unit/L-PER-K")
    TON_FG = URIRef("http://qudt.org/vocab/unit/TON_FG")
    ERG_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM3")
    DecaPA = URIRef("http://qudt.org/vocab/unit/DecaPA")
    KiloCAL_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM-SEC-DEG_C")
    MegaPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-BAR")
    PINT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-SEC")
    BIT_PER_M = URIRef("http://qudt.org/vocab/unit/BIT-PER-M")
    PetaBQ = URIRef("http://qudt.org/vocab/unit/PetaBQ")
    ERG = URIRef("http://qudt.org/vocab/unit/ERG")
    C_Ab = URIRef("http://qudt.org/vocab/unit/C_Ab")
    HectoPA = URIRef("http://qudt.org/vocab/unit/HectoPA")
    MicroM_PER_N = URIRef("http://qudt.org/vocab/unit/MicroM-PER-N")
    LB_MOL = URIRef("http://qudt.org/vocab/unit/LB-MOL")
    HZ = URIRef("http://qudt.org/vocab/unit/HZ")
    N_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M")
    PERCENT_PER_DAY = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DAY")
    GM_PER_L = URIRef("http://qudt.org/vocab/unit/GM-PER-L")
    MicroGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3")
    TONNE_PER_HA = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA")
    ExaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaJ-PER-SEC")
    KiloGM_F = URIRef("http://qudt.org/vocab/unit/KiloGM_F")
    BTU_IT_PER_LB_F_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_R")
    J_M_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-M-PER-MOL")
    LB_IN = URIRef("http://qudt.org/vocab/unit/LB-IN")
    LB_PER_FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-LB_F-SEC")
    NUM_PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliM3")
    KiloPA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-K")
    POISE = URIRef("http://qudt.org/vocab/unit/POISE")
    FC = URIRef("http://qudt.org/vocab/unit/FC")
    N_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-PER-RAD")
    LUX_SEC = URIRef("http://qudt.org/vocab/unit/LUX-SEC")
    MicroGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-K")
    GM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-BAR")
    DYN_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM3")
    GI_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-MIN")
    CentiM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-M3")
    KiloGM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MilliM")
    M_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-BAR")
    NUM_PER_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-YR")
    FT_PER_HR = URIRef("http://qudt.org/vocab/unit/FT-PER-HR")
    MebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M")
    SV = URIRef("http://qudt.org/vocab/unit/SV")
    BQ = URIRef("http://qudt.org/vocab/unit/BQ")
    BARN_PER_EV = URIRef("http://qudt.org/vocab/unit/BARN-PER-EV")
    MI_PER_SEC = URIRef("http://qudt.org/vocab/unit/MI-PER-SEC")
    PER_M = URIRef("http://qudt.org/vocab/unit/PER-M")
    J_PER_T = URIRef("http://qudt.org/vocab/unit/J-PER-T")
    LM_PER_W = URIRef("http://qudt.org/vocab/unit/LM-PER-W")
    MilliL_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-BAR")
    KiloGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-K")
    PlanckForce = URIRef("http://qudt.org/vocab/unit/PlanckForce")
    IN_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-DEG_F")
    GM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM_F-PER-CentiM2")
    SLUG_PER_DAY = URIRef("http://qudt.org/vocab/unit/SLUG-PER-DAY")
    KiloTONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloTONNE-PER-YR")
    DecaPOISE = URIRef("http://qudt.org/vocab/unit/DecaPOISE")
    CAL_IT = URIRef("http://qudt.org/vocab/unit/CAL_IT")
    M2_HZ = URIRef("http://qudt.org/vocab/unit/M2-HZ")
    TebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M3")
    CAL_TH_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM-K")
    WB_PER_M = URIRef("http://qudt.org/vocab/unit/WB-PER-M")
    PINT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-HR")
    MicroM = URIRef("http://qudt.org/vocab/unit/MicroM")
    GI = URIRef("http://qudt.org/vocab/unit/GI")
    ATM_T = URIRef("http://qudt.org/vocab/unit/ATM_T")
    MilliL_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY")
    TebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M2")
    M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M-PER-SEC2")
    KiloGM_PER_M2_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC2")
    LB_IN2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_UK-LB_F-SEC")
    CentiM3_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR")
    HZ_PER_V = URIRef("http://qudt.org/vocab/unit/HZ-PER-V")
    KiloGM_M2_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M2-PER-SEC")
    M2 = URIRef("http://qudt.org/vocab/unit/M2")
    MilliGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-BAR")
    KiloCAL_PER_MOL_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL-DEG_C")
    PicoMOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3-SEC")
    KiloC_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M2")
    GigaPA_CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/GigaPA-CentiM3-PER-GM")
    L_PER_HR_K = URIRef("http://qudt.org/vocab/unit/L-PER-HR-K")
    DECADE = URIRef("http://qudt.org/vocab/unit/DECADE")
    W_PER_IN2 = URIRef("http://qudt.org/vocab/unit/W-PER-IN2")
    KiloGM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-K")
    KiloW_PER_M2_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M2-K")
    PetaV_A = URIRef("http://qudt.org/vocab/unit/PetaV-A")
    FT_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-SEC")
    LB_F_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN")
    YD2 = URIRef("http://qudt.org/vocab/unit/YD2")
    MicroMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-SEC")
    OZ_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_UK")
    DIOPTER = URIRef("http://qudt.org/vocab/unit/DIOPTER")
    PPTH = URIRef("http://qudt.org/vocab/unit/PPTH")
    W_HR = URIRef("http://qudt.org/vocab/unit/W-HR")
    FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-SEC-DEG_F")
    LB_PER_M3 = URIRef("http://qudt.org/vocab/unit/LB-PER-M3")
    KiloCAL_Mean = URIRef("http://qudt.org/vocab/unit/KiloCAL_Mean")
    HA = URIRef("http://qudt.org/vocab/unit/HA")
    C_PER_MOL = URIRef("http://qudt.org/vocab/unit/C-PER-MOL")
    SCF = URIRef("http://qudt.org/vocab/unit/SCF")
    GAL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-SEC")
    GM_PER_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY")
    BTU_IT_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT3")
    GigaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBIT-PER-SEC")
    PER_T_SEC = URIRef("http://qudt.org/vocab/unit/PER-T-SEC")
    Flight = URIRef("http://qudt.org/vocab/unit/Flight")
    IU = URIRef("http://qudt.org/vocab/unit/IU")
    LB_F_PER_LB = URIRef("http://qudt.org/vocab/unit/LB_F-PER-LB")
    KiloA_PER_M = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M")
    FemtoGM_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-L")
    CentiM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-BAR")
    DeciB_ISO = URIRef("http://qudt.org/vocab/unit/DeciB_ISO")
    MilliGM_PER_L = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L")
    MilliPA_PER_M = URIRef("http://qudt.org/vocab/unit/MilliPA-PER-M")
    OZ_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-YD3")
    KiloGM_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M2")
    KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM")
    MI_US2 = URIRef("http://qudt.org/vocab/unit/MI_US2")
    DARCY = URIRef("http://qudt.org/vocab/unit/DARCY")
    KiloGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-BAR")
    GibiBIT = URIRef("http://qudt.org/vocab/unit/GibiBIT")
    PicoPA_PER_KiloM = URIRef("http://qudt.org/vocab/unit/PicoPA-PER-KiloM")
    PlanckCharge = URIRef("http://qudt.org/vocab/unit/PlanckCharge")
    FT3_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN")
    NanoT = URIRef("http://qudt.org/vocab/unit/NanoT")
    N_M_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-RAD")
    IN3 = URIRef("http://qudt.org/vocab/unit/IN3")
    QT_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_US-PER-DAY")
    KiloGM_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-M2")
    TON_UK_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-YD3")
    IN_PER_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-PSI")
    PER_V = URIRef("http://qudt.org/vocab/unit/PER-V")
    MOL_PER_M2_SEC_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-SR")
    HectoPA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/HectoPA-M3-PER-SEC")
    N_M_PER_MIN_Angle = URIRef("http://qudt.org/vocab/unit/N-M-PER-MIN_Angle")
    CentiM_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-K")
    DeciM = URIRef("http://qudt.org/vocab/unit/DeciM")
    HP_Metric = URIRef("http://qudt.org/vocab/unit/HP_Metric")
    MegaV_A = URIRef("http://qudt.org/vocab/unit/MegaV-A")
    MicroGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-KiloGM")
    GM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L2")
    S_PER_M = URIRef("http://qudt.org/vocab/unit/S-PER-M")
    L = URIRef("http://qudt.org/vocab/unit/L")
    BTU_IT_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT-PER-FT2-HR-DEG_F")
    MilliL = URIRef("http://qudt.org/vocab/unit/MilliL")
    OZ_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_UK")
    T_M = URIRef("http://qudt.org/vocab/unit/T-M")
    PA_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC")
    OERSTED_CentiM = URIRef("http://qudt.org/vocab/unit/OERSTED-CentiM")
    PA_SEC = URIRef("http://qudt.org/vocab/unit/PA-SEC")
    Z = URIRef("http://qudt.org/vocab/unit/Z")
    C_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-CentiM2")
    PER_MilliM = URIRef("http://qudt.org/vocab/unit/PER-MilliM")
    LY = URIRef("http://qudt.org/vocab/unit/LY")
    QT_US = URIRef("http://qudt.org/vocab/unit/QT_US")
    PetaC = URIRef("http://qudt.org/vocab/unit/PetaC")
    BQ_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-PER-M3")
    CentiM3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-K")
    V_A = URIRef("http://qudt.org/vocab/unit/V-A")
    SEC = URIRef("http://qudt.org/vocab/unit/SEC")
    BTU_TH_PER_FT2_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-MIN")
    TeraW = URIRef("http://qudt.org/vocab/unit/TeraW")
    DEG_C = URIRef("http://qudt.org/vocab/unit/DEG_C")
    KiloN = URIRef("http://qudt.org/vocab/unit/KiloN")
    L_PER_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-BAR")
    MicroH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-OHM")
    PicoL = URIRef("http://qudt.org/vocab/unit/PicoL")
    MebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M3")
    T = URIRef("http://qudt.org/vocab/unit/T")
    BTU_TH_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC-FT2-DEG_F")
    THM_US = URIRef("http://qudt.org/vocab/unit/THM_US")
    SLUG_PER_FT3 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT3")
    GRAY = URIRef("http://qudt.org/vocab/unit/GRAY")
    CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-SEC")
    NTU = URIRef("http://qudt.org/vocab/unit/NTU")
    M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC")
    KibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M2")
    KiloGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloGM")
    REM = URIRef("http://qudt.org/vocab/unit/REM")
    MilliGM_PER_HA = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HA")
    IN3_PER_LB = URIRef("http://qudt.org/vocab/unit/IN3-PER-LB")
    CAL_MEAN = URIRef("http://qudt.org/vocab/unit/CAL_MEAN")
    MI_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI-PER-MIN")
    MilliGM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR-K")
    DEG2 = URIRef("http://qudt.org/vocab/unit/DEG2")
    MACH = URIRef("http://qudt.org/vocab/unit/MACH")
    RAD_PER_M = URIRef("http://qudt.org/vocab/unit/RAD-PER-M")
    H_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/H_Stat-PER-CentiM")
    IN3_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN3-PER-MIN")
    BTU_IT_PER_LB_F_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F-DEG_F")
    AttoFARAD = URIRef("http://qudt.org/vocab/unit/AttoFARAD")
    M2_HR_DEG_C_PER_KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/M2-HR-DEG_C-PER-KiloCAL_IT")
    MilliM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliM-PER-K")
    PK_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-MIN")
    CAL_IT_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM")
    MilliBQ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-GM")
    GibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M")
    M3 = URIRef("http://qudt.org/vocab/unit/M3")
    OZ = URIRef("http://qudt.org/vocab/unit/OZ")
    Standard = URIRef("http://qudt.org/vocab/unit/Standard")
    PERMITTIVITY_REL = URIRef("http://qudt.org/vocab/unit/PERMITTIVITY_REL")
    PicoS = URIRef("http://qudt.org/vocab/unit/PicoS")
    HectoPA_PER_HR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-HR")
    M_K_PER_W = URIRef("http://qudt.org/vocab/unit/M-K-PER-W")
    YottaC = URIRef("http://qudt.org/vocab/unit/YottaC")
    KiloBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBIT-PER-SEC")
    N_PER_CentiM = URIRef("http://qudt.org/vocab/unit/N-PER-CentiM")
    BTU_60DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_60DEG_F")
    MilliV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive-PER-K")
    A_HR = URIRef("http://qudt.org/vocab/unit/A-HR")
    EV = URIRef("http://qudt.org/vocab/unit/EV")
    DEG_PER_M = URIRef("http://qudt.org/vocab/unit/DEG-PER-M")
    GM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M6")
    ENZ = URIRef("http://qudt.org/vocab/unit/ENZ")
    KiloM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM-PER-SEC2")
    MilliT = URIRef("http://qudt.org/vocab/unit/MilliT")
    QT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-MIN")
    V_PER_MilliM = URIRef("http://qudt.org/vocab/unit/V-PER-MilliM")
    MicroPA = URIRef("http://qudt.org/vocab/unit/MicroPA")
    MebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/MebiBIT-PER-M2")
    MegaV_PER_M = URIRef("http://qudt.org/vocab/unit/MegaV-PER-M")
    V_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/V-IN2-PER-LB_F")
    A_SEC = URIRef("http://qudt.org/vocab/unit/A-SEC")
    PPTR = URIRef("http://qudt.org/vocab/unit/PPTR")
    CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM3")
    MicroGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-MIN")
    MicroMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM")
    MOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM")
    PK_US_DRY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY")
    N = URIRef("http://qudt.org/vocab/unit/N")
    T_SEC = URIRef("http://qudt.org/vocab/unit/T-SEC")
    PERM_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_23DEG_C")
    NanoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-DAY")
    A_HR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DEG_C")
    PlanckFrequency = URIRef("http://qudt.org/vocab/unit/PlanckFrequency")
    TON_US_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_US-PER-HR")
    MilliGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-HR")
    PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PER-DEG_C")
    LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-FT2")
    LUX = URIRef("http://qudt.org/vocab/unit/LUX")
    GM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-CentiPOISE")
    KiloYR = URIRef("http://qudt.org/vocab/unit/KiloYR")
    PERCENT_PER_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliPA-SEC")
    PA2_SEC = URIRef("http://qudt.org/vocab/unit/PA2-SEC")
    MilliGM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-MilliPA-SEC")
    PA_M0dot5 = URIRef("http://qudt.org/vocab/unit/PA-M0dot5")
    FT_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/FT_H2O_39dot2DEG_F")
    C_M = URIRef("http://qudt.org/vocab/unit/C-M")
    KiloBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT")
    OZ_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-FT2-PER-IN3-LB_F-SEC")
    LB_PER_YD2 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD2")
    N_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-M-PER-M2")
    HectoPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-BAR")
    MHO = URIRef("http://qudt.org/vocab/unit/MHO")
    MegaTOE = URIRef("http://qudt.org/vocab/unit/MegaTOE")
    MilliV_PER_V = URIRef("http://qudt.org/vocab/unit/MilliV-PER-V")
    PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-PSI")
    MilliGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN")
    TON_US_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_US-PER-YD3")
    MicroKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MicroKAT-PER-L")
    GigaOHM = URIRef("http://qudt.org/vocab/unit/GigaOHM")
    PK_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-DAY")
    Quarter_UK = URIRef("http://qudt.org/vocab/unit/Quarter_UK")
    OZ_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ-PER-DAY")
    SLUG_PER_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-SEC")
    GigaEV = URIRef("http://qudt.org/vocab/unit/GigaEV")
    V_PER_M2 = URIRef("http://qudt.org/vocab/unit/V-PER-M2")
    GRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/GRAY-PER-SEC")
    A_PER_J = URIRef("http://qudt.org/vocab/unit/A-PER-J")
    A_PER_M2_K2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2-K2")
    MilliM_HG = URIRef("http://qudt.org/vocab/unit/MilliM_HG")
    CAL_IT_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-DEG_C")
    KiloGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-K")
    TeraFLOPS = URIRef("http://qudt.org/vocab/unit/TeraFLOPS")
    OZ_SEC_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN6")
    PicoSEC = URIRef("http://qudt.org/vocab/unit/PicoSEC")
    C2_M2_PER_J = URIRef("http://qudt.org/vocab/unit/C2-M2-PER-J")
    PicoFARAD = URIRef("http://qudt.org/vocab/unit/PicoFARAD")
    V_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/V-SEC-PER-M")
    M2_PER_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ2")
    KiloOHM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-K")
    DYN_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-PER-CentiM")
    PER_YD3 = URIRef("http://qudt.org/vocab/unit/PER-YD3")
    M_PER_FARAD = URIRef("http://qudt.org/vocab/unit/M-PER-FARAD")
    MilliCD = URIRef("http://qudt.org/vocab/unit/MilliCD")
    MilliFARAD = URIRef("http://qudt.org/vocab/unit/MilliFARAD")
    MegaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M2")
    YD = URIRef("http://qudt.org/vocab/unit/YD")
    GM_F = URIRef("http://qudt.org/vocab/unit/GM_F")
    MegaPA_PER_K = URIRef("http://qudt.org/vocab/unit/MegaPA-PER-K")
    GigaA = URIRef("http://qudt.org/vocab/unit/GigaA")
    PicoMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M3")
    CentiM2_PER_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-ERG")
    MicroBQ_PER_L = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-L")
    LB_SEC_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-YD3")
    YD_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC")
    MilliC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliC-PER-M3")
    C = URIRef("http://qudt.org/vocab/unit/C")
    REV_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/REV-PER-SEC2")
    N_M_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-RAD")
    FRACTION = URIRef("http://qudt.org/vocab/unit/FRACTION")
    KiloR = URIRef("http://qudt.org/vocab/unit/KiloR")
    YD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/YD-PER-SEC2")
    PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/PER-KiloGM2")
    KiloFARAD = URIRef("http://qudt.org/vocab/unit/KiloFARAD")
    KN = URIRef("http://qudt.org/vocab/unit/KN")
    BTU_IT_PER_LB_MOL = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-MOL")
    OHM = URIRef("http://qudt.org/vocab/unit/OHM")
    FT2 = URIRef("http://qudt.org/vocab/unit/FT2")
    N_M_SEC = URIRef("http://qudt.org/vocab/unit/N-M-SEC")
    KiloOHM = URIRef("http://qudt.org/vocab/unit/KiloOHM")
    V_Ab = URIRef("http://qudt.org/vocab/unit/V_Ab")
    C_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM2")
    KiloGM_PER_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-K")
    ExaBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-M")
    KiloGM_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-MilliM2")
    LB_IN2_PER_FT3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-FT3-LB_F-SEC")
    W_M2 = URIRef("http://qudt.org/vocab/unit/W-M2")
    KiloGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC")
    OZ_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ-PER-SEC")
    MicroL = URIRef("http://qudt.org/vocab/unit/MicroL")
    N_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-PER-M3")
    TORR = URIRef("http://qudt.org/vocab/unit/TORR")
    KiloGM_PER_L = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L")
    NanoA_PER_K = URIRef("http://qudt.org/vocab/unit/NanoA-PER-K")
    L_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-K")
    PPT = URIRef("http://qudt.org/vocab/unit/PPT")
    PlanckTemperature = URIRef("http://qudt.org/vocab/unit/PlanckTemperature")
    TONNE_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-BAR")
    KibiBYTE = URIRef("http://qudt.org/vocab/unit/KibiBYTE")
    MegaN_M = URIRef("http://qudt.org/vocab/unit/MegaN-M")
    MOL = URIRef("http://qudt.org/vocab/unit/MOL")
    QT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_US-PER-SEC")
    MegaGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaGM-PER-M3")
    FARAD = URIRef("http://qudt.org/vocab/unit/FARAD")
    MicroMOL_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-HR")
    FT4 = URIRef("http://qudt.org/vocab/unit/FT4")
    DEG_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-MIN")
    BTU_TH_FT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-FT2-HR-DEG_F")
    PPTM = URIRef("http://qudt.org/vocab/unit/PPTM")
    FemtoA = URIRef("http://qudt.org/vocab/unit/FemtoA")
    H_PER_M = URIRef("http://qudt.org/vocab/unit/H-PER-M")
    LB_SEC_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_US")
    LB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2")
    K_PER_MIN = URIRef("http://qudt.org/vocab/unit/K-PER-MIN")
    A_PER_A_HR = URIRef("http://qudt.org/vocab/unit/A-PER-A-HR")
    BTU_IT_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_R")
    MilliGM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-POISE")
    CentiM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC2")
    NanoS = URIRef("http://qudt.org/vocab/unit/NanoS")
    W_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-HR-PER-M2")
    BBL = URIRef("http://qudt.org/vocab/unit/BBL")
    MicroW = URIRef("http://qudt.org/vocab/unit/MicroW")
    MilliGM_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-DAY")
    LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC")
    M2_PER_M2 = URIRef("http://qudt.org/vocab/unit/M2-PER-M2")
    PicoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L")
    PK_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-DAY")
    SLUG_PER_MIN = URIRef("http://qudt.org/vocab/unit/SLUG-PER-MIN")
    KiloMOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-SEC")
    C_PER_M = URIRef("http://qudt.org/vocab/unit/C-PER-M")
    BTU_IT_PER_SEC_FT_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT-DEG_R")
    CAL_TH_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-K")
    PDL_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-FT2")
    TON_Metric_PER_SEC = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC")
    KiloLB_F_PER_FT = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-FT")
    MilliMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-KiloGM")
    MegaJ_PER_M3 = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-M3")
    GAL_IMP = URIRef("http://qudt.org/vocab/unit/GAL_IMP")
    CentiM3_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-BAR")
    NAT = URIRef("http://qudt.org/vocab/unit/NAT")
    FemtoC = URIRef("http://qudt.org/vocab/unit/FemtoC")
    DEG_C_PER_YR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-YR")
    IN_PER_MIN = URIRef("http://qudt.org/vocab/unit/IN-PER-MIN")
    BTU_IT_PER_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB")
    PERCENT_PER_V = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-V")
    EV_PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/EV-PER-ANGSTROM")
    MilliA_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliA-PER-BAR")
    EV_SEC = URIRef("http://qudt.org/vocab/unit/EV-SEC")
    LB_PER_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-DAY")
    NanoN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/NanoN-M-PER-M2")
    LB_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN6")
    MilliGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-CentiM2")
    CentiM3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-BAR")
    GRAIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-GAL_US")
    PERCENT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_UK")
    MilliGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3")
    DeciB_MilliW_PER_MegaHZ = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW-PER-MegaHZ")
    MilliGM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-PA-SEC")
    YR_Sidereal = URIRef("http://qudt.org/vocab/unit/YR_Sidereal")
    N_M_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-M-PER-KiloGM")
    KiloS = URIRef("http://qudt.org/vocab/unit/KiloS")
    YD3_PER_DAY = URIRef("http://qudt.org/vocab/unit/YD3-PER-DAY")
    L_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-M2")
    J_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2")
    KiloCAL_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2")
    DEG_C_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-K")
    M2_SR = URIRef("http://qudt.org/vocab/unit/M2-SR")
    PERM_Metric = URIRef("http://qudt.org/vocab/unit/PERM_Metric")
    M2_PER_HZ = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ")
    CentiM2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-V-SEC")
    LB_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_US")
    GAUSS = URIRef("http://qudt.org/vocab/unit/GAUSS")
    KiloGM_PER_MegaBTU_IT = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MegaBTU_IT")
    MegaW = URIRef("http://qudt.org/vocab/unit/MegaW")
    HR_PER_FT2 = URIRef("http://qudt.org/vocab/unit/HR-PER-FT2")
    HART_PER_SEC = URIRef("http://qudt.org/vocab/unit/HART-PER-SEC")
    PK_UK = URIRef("http://qudt.org/vocab/unit/PK_UK")
    YR_Common = URIRef("http://qudt.org/vocab/unit/YR_Common")
    PicoMOL_PER_M_W_SEC = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M-W-SEC")
    LB_F_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN")
    PERCENT_PER_DecaKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaKiloCount")
    CentiM3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-BAR")
    PERCENT_PER_BAR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-BAR")
    BTU_IT_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC")
    PARSEC = URIRef("http://qudt.org/vocab/unit/PARSEC")
    NUM_PER_HectoGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-HectoGM")
    PPQ = URIRef("http://qudt.org/vocab/unit/PPQ")
    MI_N_PER_MIN = URIRef("http://qudt.org/vocab/unit/MI_N-PER-MIN")
    BAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-L-PER-SEC")
    C_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM-SEC")
    FUR = URIRef("http://qudt.org/vocab/unit/FUR")
    K_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PA-PER-SEC")
    KiloGM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-L-BAR")
    CentiM3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-BAR")
    TONNE_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-K")
    KiloN_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG-M")
    MilliGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MilliL")
    MilliGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-BAR")
    A_HR_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-DeciM3")
    KiloCAL_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-MIN")
    LB_MIN_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_UK")
    NT = URIRef("http://qudt.org/vocab/unit/NT")
    GAL_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-MIN")
    KibiBIT = URIRef("http://qudt.org/vocab/unit/KibiBIT")
    MicroGM_PER_CentiM2_WK = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2-WK")
    NanoSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-SEC")
    MOHM = URIRef("http://qudt.org/vocab/unit/MOHM")
    BTU_IT_PER_LB_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB_F")
    FT3_PER_MIN_FT2 = URIRef("http://qudt.org/vocab/unit/FT3-PER-MIN-FT2")
    BTU_IT_PER_MOL_LB = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB")
    MicroC_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M2")
    POISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/POISE-PER-BAR")
    KiloGM_F_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-CentiM2")
    PINT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-HR")
    MegaHZ_PER_T = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-T")
    BTU_IT = URIRef("http://qudt.org/vocab/unit/BTU_IT")
    MicroMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2")
    DeciB = URIRef("http://qudt.org/vocab/unit/DeciB")
    MilliM2 = URIRef("http://qudt.org/vocab/unit/MilliM2")
    CentiMOL = URIRef("http://qudt.org/vocab/unit/CentiMOL")
    CentiM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN")
    DeciM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MOL")
    MegaEV_FemtoM = URIRef("http://qudt.org/vocab/unit/MegaEV-FemtoM")
    MOMME_Textile = URIRef("http://qudt.org/vocab/unit/MOMME_Textile")
    HectoM = URIRef("http://qudt.org/vocab/unit/HectoM")
    FT_LB_F = URIRef("http://qudt.org/vocab/unit/FT-LB_F")
    IN3_PER_HR = URIRef("http://qudt.org/vocab/unit/IN3-PER-HR")
    KN_PER_SEC = URIRef("http://qudt.org/vocab/unit/KN-PER-SEC")
    ST_PER_K = URIRef("http://qudt.org/vocab/unit/ST-PER-K")
    TON_Metric_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-K")
    TON = URIRef("http://qudt.org/vocab/unit/TON")
    DeciB_A = URIRef("http://qudt.org/vocab/unit/DeciB_A")
    P = URIRef("http://qudt.org/vocab/unit/P")
    J_M2 = URIRef("http://qudt.org/vocab/unit/J-M2")
    RAD_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC2")
    BBL_UK_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-SEC")
    RAD_PER_SEC = URIRef("http://qudt.org/vocab/unit/RAD-PER-SEC")
    C_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-PER-KiloGM")
    TON_SHORT_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-YD3")
    IN_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC-PSI")
    PA_PER_M = URIRef("http://qudt.org/vocab/unit/PA-PER-M")
    GAL_US = URIRef("http://qudt.org/vocab/unit/GAL_US")
    GigaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaBYTE-PER-SEC")
    MicroSV = URIRef("http://qudt.org/vocab/unit/MicroSV")
    CWT_LONG = URIRef("http://qudt.org/vocab/unit/CWT_LONG")
    PicoH = URIRef("http://qudt.org/vocab/unit/PicoH")
    ExbiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M")
    TON_SHORT_PER_PSI = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-PSI")
    V_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/V-PER-L-MIN")
    PK_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-MIN")
    BU_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-SEC")
    GM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-CentiM3")
    N_M_PER_W0dot5 = URIRef("http://qudt.org/vocab/unit/N-M-PER-W0dot5")
    MilliL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M2-DAY")
    DecaL = URIRef("http://qudt.org/vocab/unit/DecaL")
    MilliOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-K")
    KiloGM_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-FT2")
    MilliSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-HR")
    ERG_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM-SEC")
    GM_PER_HZ = URIRef("http://qudt.org/vocab/unit/GM-PER-HZ")
    KiloGM_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM2")
    LB_HR_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-IN3")
    NUM_PER_NanoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-NanoL")
    LM_HR = URIRef("http://qudt.org/vocab/unit/LM-HR")
    DecaARE = URIRef("http://qudt.org/vocab/unit/DecaARE")
    MicroH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MicroH-PER-KiloOHM")
    LB_MIN_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-FT3")
    H_Ab = URIRef("http://qudt.org/vocab/unit/H_Ab")
    KiloBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloBQ-PER-KiloGM")
    ExaC = URIRef("http://qudt.org/vocab/unit/ExaC")
    KiloC = URIRef("http://qudt.org/vocab/unit/KiloC")
    KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloMOL")
    GigaC = URIRef("http://qudt.org/vocab/unit/GigaC")
    PER_MO = URIRef("http://qudt.org/vocab/unit/PER-MO")
    W_M2_PER_SR = URIRef("http://qudt.org/vocab/unit/W-M2-PER-SR")
    YD3_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD3-PER-PSI")
    LB_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-IN3-LB_F-SEC")
    MicroN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroN-M-PER-M2")
    MilliJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-M2")
    PicoJ = URIRef("http://qudt.org/vocab/unit/PicoJ")
    MegaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-M")
    MegaV_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive-HR")
    BBL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_US-PER-MIN")
    TeraW_HR_PER_YR = URIRef("http://qudt.org/vocab/unit/TeraW-HR-PER-YR")
    CAL_TH_PER_CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-MIN")
    MilliGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-BAR")
    H_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/H-PER-KiloOHM")
    PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-PER-SEC")
    CAL_15_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_15_DEG_C")
    KIP_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KIP_F-PER-IN2")
    YD3_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD3-PER-MIN")
    PA_M0pt5 = URIRef("http://qudt.org/vocab/unit/PA-M0pt5")
    BTU_IT_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-HR-DEG_F")
    KiloCAL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-CentiM2-SEC")
    N_M2_PER_KiloGM2 = URIRef("http://qudt.org/vocab/unit/N-M2-PER-KiloGM2")
    V_Stat_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-PER-CentiM")
    M2_PER_SR = URIRef("http://qudt.org/vocab/unit/M2-PER-SR")
    MegaPSI = URIRef("http://qudt.org/vocab/unit/MegaPSI")
    GM_PER_L_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-PA-SEC")
    MicroM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MIN")
    KiloW_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-DEG_C")
    PA_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-L-PER-SEC")
    RT = URIRef("http://qudt.org/vocab/unit/RT")
    TBSP = URIRef("http://qudt.org/vocab/unit/TBSP")
    A_M2_PER_J_SEC = URIRef("http://qudt.org/vocab/unit/A-M2-PER-J-SEC")
    FT_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-PER-MIN")
    DeciM3_PER_MIN = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-MIN")
    MicroMHO = URIRef("http://qudt.org/vocab/unit/MicroMHO")
    FemtoMOL = URIRef("http://qudt.org/vocab/unit/FemtoMOL")
    DEGREE_BAUME_US_HEAVY = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_HEAVY")
    MegaJ = URIRef("http://qudt.org/vocab/unit/MegaJ")
    PA = URIRef("http://qudt.org/vocab/unit/PA")
    KiloGM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-HR-BAR")
    GAL_US_DRY = URIRef("http://qudt.org/vocab/unit/GAL_US_DRY")
    MicroC = URIRef("http://qudt.org/vocab/unit/MicroC")
    MegaLB_F = URIRef("http://qudt.org/vocab/unit/MegaLB_F")
    GigaW_HR = URIRef("http://qudt.org/vocab/unit/GigaW-HR")
    OZ_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN3")
    PERCENT_FT_SEC_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-SEC-PER-LB")
    GM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-PA-SEC")
    PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/PER-KiloGM-SEC")
    PER_KiloV_A_HR = URIRef("http://qudt.org/vocab/unit/PER-KiloV-A-HR")
    MegaSEC = URIRef("http://qudt.org/vocab/unit/MegaSEC")
    AttoJ = URIRef("http://qudt.org/vocab/unit/AttoJ")
    MicroMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-SEC")
    NanoS_PER_M = URIRef("http://qudt.org/vocab/unit/NanoS-PER-M")
    MilliL_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-CentiM2-SEC")
    TONNE_PER_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-BAR")
    GRAIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/GRAIN-PER-M3")
    MicroM3_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-MilliL")
    N_PER_M = URIRef("http://qudt.org/vocab/unit/N-PER-M")
    C_M2 = URIRef("http://qudt.org/vocab/unit/C-M2")
    OHM_M2_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-M2-PER-M")
    W_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-SEC-PER-M2")
    MilliH_PER_KiloOHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-KiloOHM")
    MilliM_HGA = URIRef("http://qudt.org/vocab/unit/MilliM_HGA")
    CentiM_PER_HR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-HR")
    GM_PER_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC")
    Hundredweight_US = URIRef("http://qudt.org/vocab/unit/Hundredweight_US")
    PDL_IN = URIRef("http://qudt.org/vocab/unit/PDL-IN")
    S = URIRef("http://qudt.org/vocab/unit/S")
    MicroIN = URIRef("http://qudt.org/vocab/unit/MicroIN")
    KiloGM_PER_M_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-MIN")
    MicroV_PER_M = URIRef("http://qudt.org/vocab/unit/MicroV-PER-M")
    MilliGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-K")
    GAL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-DAY")
    KiloCubicFT = URIRef("http://qudt.org/vocab/unit/KiloCubicFT")
    OZ_F_PER_IN3 = URIRef("http://qudt.org/vocab/unit/OZ_F-PER-IN3")
    LB_PER_IN3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-PSI")
    DEG_F_HR_FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT-IN")
    MOL_PER_L = URIRef("http://qudt.org/vocab/unit/MOL-PER-L")
    V_A_Reactive_HR = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-HR")
    RAD = URIRef("http://qudt.org/vocab/unit/RAD")
    NP = URIRef("http://qudt.org/vocab/unit/NP")
    BTU_IT_PER_SEC_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2")
    PERCENT_HR_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-FT3")
    PK_US_DRY_PER_HR = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-HR")
    GM_PER_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-BAR")
    PlanckPressure = URIRef("http://qudt.org/vocab/unit/PlanckPressure")
    NanoSV_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-HR")
    FT_H2O = URIRef("http://qudt.org/vocab/unit/FT_H2O")
    A_PER_PA = URIRef("http://qudt.org/vocab/unit/A-PER-PA")
    PER_MilliM3 = URIRef("http://qudt.org/vocab/unit/PER-MilliM3")
    L_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-K")
    PERCENT_MIN_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-IN3")
    V_PER_MicroSEC = URIRef("http://qudt.org/vocab/unit/V-PER-MicroSEC")
    KiloBYTE = URIRef("http://qudt.org/vocab/unit/KiloBYTE")
    KiloCAL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MIN")
    BBL_US_DRY = URIRef("http://qudt.org/vocab/unit/BBL_US_DRY")
    FA = URIRef("http://qudt.org/vocab/unit/FA")
    W_PER_M3 = URIRef("http://qudt.org/vocab/unit/W-PER-M3")
    V_M = URIRef("http://qudt.org/vocab/unit/V-M")
    DEG_F_SEC_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_TH")
    DeciB_C = URIRef("http://qudt.org/vocab/unit/DeciB_C")
    MESH = URIRef("http://qudt.org/vocab/unit/MESH")
    PebiBYTE = URIRef("http://qudt.org/vocab/unit/PebiBYTE")
    SLUG_PER_HR = URIRef("http://qudt.org/vocab/unit/SLUG-PER-HR")
    LB_FT2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-IN3-LB_F-SEC")
    SUSCEPTIBILITY_MAG = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_MAG")
    M4 = URIRef("http://qudt.org/vocab/unit/M4")
    J_PER_KiloGM_DEG_C = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-DEG_C")
    MOL_PER_KiloGM_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-BAR")
    MilliWB = URIRef("http://qudt.org/vocab/unit/MilliWB")
    SV_PER_HR = URIRef("http://qudt.org/vocab/unit/SV-PER-HR")
    MilliBAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-M3-PER-SEC")
    MilliH_PER_OHM = URIRef("http://qudt.org/vocab/unit/MilliH-PER-OHM")
    V_Stat = URIRef("http://qudt.org/vocab/unit/V_Stat")
    J_PER_M = URIRef("http://qudt.org/vocab/unit/J-PER-M")
    KiloMOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-BAR")
    PER_SEC_SR_M2 = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR-M2")
    Gs = URIRef("http://qudt.org/vocab/unit/Gs")
    SHANNON = URIRef("http://qudt.org/vocab/unit/SHANNON")
    TONNE_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-K")
    BTU_TH_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-SEC-DEG_F")
    BTU_IT_PER_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_F")
    RAD_PER_MIN = URIRef("http://qudt.org/vocab/unit/RAD-PER-MIN")
    DEGREE_BAUME_US_LIGHT = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME_US_LIGHT")
    PER_MicroM = URIRef("http://qudt.org/vocab/unit/PER-MicroM")
    W_PER_FT2 = URIRef("http://qudt.org/vocab/unit/W-PER-FT2")
    MebiBYTE = URIRef("http://qudt.org/vocab/unit/MebiBYTE")
    ATM = URIRef("http://qudt.org/vocab/unit/ATM")
    BU_UK = URIRef("http://qudt.org/vocab/unit/BU_UK")
    M3_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-M2")
    KiloGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-K")
    KiloJ_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-MIN")
    J_PER_MOL_K = URIRef("http://qudt.org/vocab/unit/J-PER-MOL-K")
    TeraC = URIRef("http://qudt.org/vocab/unit/TeraC")
    OZ_PER_FT2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-FT2")
    SLUG_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT-SEC")
    E = URIRef("http://qudt.org/vocab/unit/E")
    PA_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PA-M2-PER-KiloGM")
    DYN_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-CentiM")
    GM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-M3-L")
    NanoS_PER_CentiM = URIRef("http://qudt.org/vocab/unit/NanoS-PER-CentiM")
    C_PER_M3 = URIRef("http://qudt.org/vocab/unit/C-PER-M3")
    GibiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M2")
    PER_MegaPA = URIRef("http://qudt.org/vocab/unit/PER-MegaPA")
    PERCENT_IN2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-IN2-PER-LB_F-SEC")
    PER_DAY = URIRef("http://qudt.org/vocab/unit/PER-DAY")
    PER_LB = URIRef("http://qudt.org/vocab/unit/PER-LB")
    KiloCAL_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-SEC")
    M2_PER_N = URIRef("http://qudt.org/vocab/unit/M2-PER-N")
    ST_PER_PA = URIRef("http://qudt.org/vocab/unit/ST-PER-PA")
    W_PER_SR_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-SR-M2")
    ZOLL = URIRef("http://qudt.org/vocab/unit/ZOLL")
    KiloGM_PER_M_HR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-HR")
    DEG_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG-PER-HR")
    PERCENT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-IN3")
    MilliGM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-CentiM3")
    OZ_PER_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD3")
    CAL_TH_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC-CentiM2-K")
    CFU = URIRef("http://qudt.org/vocab/unit/CFU")
    KiloGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-PA-SEC")
    W_PER_M2_K = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K")
    MOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MOL-PER-MOL")
    MicroJ = URIRef("http://qudt.org/vocab/unit/MicroJ")
    QT_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-HR")
    FT2_PER_BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/FT2-PER-BTU_IT-IN")
    LB_MIN_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-IN3")
    PERCENT_SEC_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-CentiM3")
    F = URIRef("http://qudt.org/vocab/unit/F")
    J_PER_M2 = URIRef("http://qudt.org/vocab/unit/J-PER-M2")
    K = URIRef("http://qudt.org/vocab/unit/K")
    MilliIN = URIRef("http://qudt.org/vocab/unit/MilliIN")
    A_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-HR-PER-KiloGM")
    HectoC = URIRef("http://qudt.org/vocab/unit/HectoC")
    PER_H = URIRef("http://qudt.org/vocab/unit/PER-H")
    W_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/W-PER-CentiM2")
    J_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-PER-MOL")
    AC = URIRef("http://qudt.org/vocab/unit/AC")
    L_PER_DAY = URIRef("http://qudt.org/vocab/unit/L-PER-DAY")
    M_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-PA")
    PER_ANGSTROM = URIRef("http://qudt.org/vocab/unit/PER-ANGSTROM")
    PlanckVolt = URIRef("http://qudt.org/vocab/unit/PlanckVolt")
    TONNE_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HA-YR")
    PH = URIRef("http://qudt.org/vocab/unit/PH")
    PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT")
    KiloGM_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC2")
    MilliGM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M6")
    IN_PER_2PiRAD = URIRef("http://qudt.org/vocab/unit/IN-PER-2PiRAD")
    LB_HR_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-YD3")
    KiloEV = URIRef("http://qudt.org/vocab/unit/KiloEV")
    MicroOHM = URIRef("http://qudt.org/vocab/unit/MicroOHM")
    KiloGM_PER_SEC3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC3-K")
    OHM_M = URIRef("http://qudt.org/vocab/unit/OHM-M")
    MOL_LB_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-SEC")
    MilliL_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-BAR")
    KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloM2")
    DeciM3_PER_HR = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-HR")
    PERCENT_PER_MilliM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MilliM")
    BIT = URIRef("http://qudt.org/vocab/unit/BIT")
    BTU_IT_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-SEC-DEG_F")
    H = URIRef("http://qudt.org/vocab/unit/H")
    W_PER_M2 = URIRef("http://qudt.org/vocab/unit/W-PER-M2")
    KiloA_HR = URIRef("http://qudt.org/vocab/unit/KiloA-HR")
    MilliA_PER_L_MIN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-L-MIN")
    MilliGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-SEC")
    MilliL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliL-PER-GM")
    SEC_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-FT2")
    A_Ab = URIRef("http://qudt.org/vocab/unit/A_Ab")
    FT3_PER_LB = URIRef("http://qudt.org/vocab/unit/FT3-PER-LB")
    KiloW_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloW-HR-PER-M2")
    EU_PER_L = URIRef("http://qudt.org/vocab/unit/EU-PER-L")
    SCM_PER_MIN = URIRef("http://qudt.org/vocab/unit/SCM-PER-MIN")
    MicroGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-BAR")
    GigaBIT = URIRef("http://qudt.org/vocab/unit/GigaBIT")
    KiloW_HR = URIRef("http://qudt.org/vocab/unit/KiloW-HR")
    FT3_PER_HR = URIRef("http://qudt.org/vocab/unit/FT3-PER-HR")
    MilliGM_MIN_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-L")
    MegaBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaBTU_IT-PER-HR")
    FT_LB_F_PER_M2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-M2")
    PER_IN3 = URIRef("http://qudt.org/vocab/unit/PER-IN3")
    W_SEC = URIRef("http://qudt.org/vocab/unit/W-SEC")
    TONNE_PER_HR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR")
    MI_N = URIRef("http://qudt.org/vocab/unit/MI_N")
    LB_SEC_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-FT3")
    TONNE_PER_DAY = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY")
    J_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM3-K")
    L_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-MIN-BAR")
    W = URIRef("http://qudt.org/vocab/unit/W")
    DEGREE_BALLING = URIRef("http://qudt.org/vocab/unit/DEGREE_BALLING")
    YD_PER_MIN = URIRef("http://qudt.org/vocab/unit/YD-PER-MIN")
    MebiBIT = URIRef("http://qudt.org/vocab/unit/MebiBIT")
    EV_M2 = URIRef("http://qudt.org/vocab/unit/EV-M2")
    NanoGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-MIN")
    PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PER-SEC2")
    MilliM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MilliM-PER-SEC2")
    MOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC")
    KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-SEC2")
    MicroV_A = URIRef("http://qudt.org/vocab/unit/MicroV-A")
    MicroC_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroC-PER-M3")
    MilliHZ = URIRef("http://qudt.org/vocab/unit/MilliHZ")
    PERCENT_PER_MO = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-MO")
    PPTM_PER_K = URIRef("http://qudt.org/vocab/unit/PPTM-PER-K")
    HR_PER_YR = URIRef("http://qudt.org/vocab/unit/HR-PER-YR")
    J_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM")
    M2_K_PER_W = URIRef("http://qudt.org/vocab/unit/M2-K-PER-W")
    QT_UK = URIRef("http://qudt.org/vocab/unit/QT_UK")
    OZ_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-FT3")
    K_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/K-PER-SEC2")
    MilliGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-HR")
    MilliL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliL-PER-M3")
    MicroM2 = URIRef("http://qudt.org/vocab/unit/MicroM2")
    LM_PER_M2 = URIRef("http://qudt.org/vocab/unit/LM-PER-M2")
    BTU_IT_FT = URIRef("http://qudt.org/vocab/unit/BTU_IT-FT")
    R = URIRef("http://qudt.org/vocab/unit/R")
    LB_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-DEG_F")
    C_Stat_PER_MOL = URIRef("http://qudt.org/vocab/unit/C_Stat-PER-MOL")
    A_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-PER-M2")
    CAL_IT_PER_SEC_CentiM2_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM2-K")
    MicroSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-MIN")
    PicoV_A = URIRef("http://qudt.org/vocab/unit/PicoV-A")
    HZ_PER_T = URIRef("http://qudt.org/vocab/unit/HZ-PER-T")
    MegaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-HR")
    GI_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_US-PER-HR")
    ERLANG = URIRef("http://qudt.org/vocab/unit/ERLANG")
    LB_FT2 = URIRef("http://qudt.org/vocab/unit/LB-FT2")
    GM_MilliM = URIRef("http://qudt.org/vocab/unit/GM-MilliM")
    CUP_US = URIRef("http://qudt.org/vocab/unit/CUP_US")
    GM_PER_L_K = URIRef("http://qudt.org/vocab/unit/GM-PER-L-K")
    DYN_SEC_PER_CentiM = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM")
    MOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3")
    TebiBYTE = URIRef("http://qudt.org/vocab/unit/TebiBYTE")
    MilliSEC = URIRef("http://qudt.org/vocab/unit/MilliSEC")
    MilliGM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-M3")
    BTU_IT_PER_HR_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2")
    NanoM_PER_MilliM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-MilliM-MegaPA")
    PER_TONNE = URIRef("http://qudt.org/vocab/unit/PER-TONNE")
    KiloN_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-DEG")
    MegaOHM_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-KiloM")
    MilliCi = URIRef("http://qudt.org/vocab/unit/MilliCi")
    AU = URIRef("http://qudt.org/vocab/unit/AU")
    CentiM3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY-K")
    OZ_M = URIRef("http://qudt.org/vocab/unit/OZ_M")
    DeciM3_PER_SEC = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-SEC")
    OZ_VOL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-HR")
    L_PER_MOL = URIRef("http://qudt.org/vocab/unit/L-PER-MOL")
    LB_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-MOL-DEG_F")
    W_PER_GM = URIRef("http://qudt.org/vocab/unit/W-PER-GM")
    BU_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-HR")
    YD3_PER_SEC = URIRef("http://qudt.org/vocab/unit/YD3-PER-SEC")
    MilliH = URIRef("http://qudt.org/vocab/unit/MilliH")
    DEG_F_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-HR")
    GM_PER_CentiM_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-SEC")
    REV = URIRef("http://qudt.org/vocab/unit/REV")
    MicroM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroM-PER-SEC")
    NanoBQ_PER_L = URIRef("http://qudt.org/vocab/unit/NanoBQ-PER-L")
    FT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_US")
    V2_PER_K2 = URIRef("http://qudt.org/vocab/unit/V2-PER-K2")
    J_PER_SEC = URIRef("http://qudt.org/vocab/unit/J-PER-SEC")
    KiloPA_M2_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloPA-M2-PER-GM")
    A_PER_GM = URIRef("http://qudt.org/vocab/unit/A-PER-GM")
    FT_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC2")
    FT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-IN3")
    M3_PER_M2 = URIRef("http://qudt.org/vocab/unit/M3-PER-M2")
    MilliC = URIRef("http://qudt.org/vocab/unit/MilliC")
    PER_M_K = URIRef("http://qudt.org/vocab/unit/PER-M-K")
    M = URIRef("http://qudt.org/vocab/unit/M")
    HP_Boiler = URIRef("http://qudt.org/vocab/unit/HP_Boiler")
    J_SEC = URIRef("http://qudt.org/vocab/unit/J-SEC")
    DAY = URIRef("http://qudt.org/vocab/unit/DAY")
    GI_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_US-PER-SEC")
    MicroA = URIRef("http://qudt.org/vocab/unit/MicroA")
    K_PER_PA = URIRef("http://qudt.org/vocab/unit/K-PER-PA")
    M_PER_YR = URIRef("http://qudt.org/vocab/unit/M-PER-YR")
    CentiM3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-HR-BAR")
    GigaW = URIRef("http://qudt.org/vocab/unit/GigaW")
    IN_HG = URIRef("http://qudt.org/vocab/unit/IN_HG")
    MilliM_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliM-PER-MIN")
    PA_PER_HR = URIRef("http://qudt.org/vocab/unit/PA-PER-HR")
    TON_Metric_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-SEC-BAR")
    MilliA_PER_IN = URIRef("http://qudt.org/vocab/unit/MilliA-PER-IN")
    PDL_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN2")
    GM_PER_CentiM2_YR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2-YR")
    KiloJ_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-DAY")
    TeraW_HR = URIRef("http://qudt.org/vocab/unit/TeraW-HR")
    TON_SHIPPING_UK = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_UK")
    PER_OZ = URIRef("http://qudt.org/vocab/unit/PER-OZ")
    LB_MIN_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-YD3")
    PFUND = URIRef("http://qudt.org/vocab/unit/PFUND")
    LB_PER_MIN_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-PSI")
    MicroBAR = URIRef("http://qudt.org/vocab/unit/MicroBAR")
    DEG = URIRef("http://qudt.org/vocab/unit/DEG")
    TON_FG_HR = URIRef("http://qudt.org/vocab/unit/TON_FG-HR")
    PERCENT_MIN_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-M3")
    W_HR_PER_L = URIRef("http://qudt.org/vocab/unit/W-HR-PER-L")
    FT_LB_F_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2-SEC")
    TEX = URIRef("http://qudt.org/vocab/unit/TEX")
    FT_US = URIRef("http://qudt.org/vocab/unit/FT_US")
    N_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-RAD")
    TON_Metric_PER_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-K")
    KiloMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3")
    FT_LB_F_PER_FT2 = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-FT2")
    KiloGM_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MOL")
    M3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM")
    MilliM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DAY")
    DecaM = URIRef("http://qudt.org/vocab/unit/DecaM")
    MilliMOL_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-SEC")
    MicroMOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-HR")
    GM_PER_M = URIRef("http://qudt.org/vocab/unit/GM-PER-M")
    KiloPA_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-BAR")
    OCTET_PER_SEC = URIRef("http://qudt.org/vocab/unit/OCTET-PER-SEC")
    unit = URIRef("http://qudt.org/vocab/unit")
    GigaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-SEC")
    NanoSEC = URIRef("http://qudt.org/vocab/unit/NanoSEC")
    LB_HR_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-IN3")
    PlanckImpedance = URIRef("http://qudt.org/vocab/unit/PlanckImpedance")
    MilliRAD_R = URIRef("http://qudt.org/vocab/unit/MilliRAD_R")
    DeciSEC = URIRef("http://qudt.org/vocab/unit/DeciSEC")
    OZ_PER_IN2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-IN2")
    MegaC = URIRef("http://qudt.org/vocab/unit/MegaC")
    BTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR")
    MegaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MegaN-M-PER-M2")
    PetaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaBIT-PER-SEC")
    PER_SEC_M3 = URIRef("http://qudt.org/vocab/unit/PER-SEC-M3")
    LB_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-DEG_F")
    L_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-MOL-SEC")
    KiloV_A_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A-PER-K")
    MilliGM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-K")
    OHM_PER_MI = URIRef("http://qudt.org/vocab/unit/OHM-PER-MI")
    CentiM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-DAY")
    AC_FT_US = URIRef("http://qudt.org/vocab/unit/AC-FT_US")
    KiloN_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M3")
    MegaBQ = URIRef("http://qudt.org/vocab/unit/MegaBQ")
    PINT_US_DRY = URIRef("http://qudt.org/vocab/unit/PINT_US_DRY")
    TON_Metric_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-BAR")
    M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL")
    CentiM3_PER_MOL = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL")
    NUM_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/NUM-PER-MilliGM")
    KiloGM_F_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-PER-MilliM2")
    KiloGM_PER_J = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-J")
    GigaN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaN-M-PER-M2")
    PicoGM_PER_L = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-L")
    ZeptoC = URIRef("http://qudt.org/vocab/unit/ZeptoC")
    KiloMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-KiloGM")
    CAL_TH_PER_G = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-G")
    CAL_TH_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2")
    NanoJ = URIRef("http://qudt.org/vocab/unit/NanoJ")
    MilliSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-SEC")
    PER_MILLE_PER_PSI = URIRef("http://qudt.org/vocab/unit/PER-MILLE-PER-PSI")
    TONNE_PER_SEC = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC")
    MicroJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroJ-PER-SEC")
    IN_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/IN-PER-DEG_F")
    FR = URIRef("http://qudt.org/vocab/unit/FR")
    CWT_SHORT = URIRef("http://qudt.org/vocab/unit/CWT_SHORT")
    GM_HR_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M6")
    K_PER_BAR = URIRef("http://qudt.org/vocab/unit/K-PER-BAR")
    M2_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-PA")
    CentiM2_MIN = URIRef("http://qudt.org/vocab/unit/CentiM2-MIN")
    BIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M2")
    MicroGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-GM")
    MilliW = URIRef("http://qudt.org/vocab/unit/MilliW")
    CD_PER_FT2 = URIRef("http://qudt.org/vocab/unit/CD-PER-FT2")
    M3_PER_YR = URIRef("http://qudt.org/vocab/unit/M3-PER-YR")
    J_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-CentiM2-DAY")
    MilliMOL_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-GM")
    DeciN = URIRef("http://qudt.org/vocab/unit/DeciN")
    CentiM_PER_YR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-YR")
    PER_IN = URIRef("http://qudt.org/vocab/unit/PER-IN")
    GM_PER_HR_K = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-K")
    GigaJ = URIRef("http://qudt.org/vocab/unit/GigaJ")
    RAYL = URIRef("http://qudt.org/vocab/unit/RAYL")
    MicroBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroBQ-PER-KiloGM")
    MicroGRAY = URIRef("http://qudt.org/vocab/unit/MicroGRAY")
    MilliS_PER_M = URIRef("http://qudt.org/vocab/unit/MilliS-PER-M")
    N_M_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-M")
    Pennyweight = URIRef("http://qudt.org/vocab/unit/Pennyweight")
    L_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-HR-BAR")
    LB_PER_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-PSI")
    LB_IN2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-IN2-PER-GAL_US-LB_F-SEC")
    PetaA = URIRef("http://qudt.org/vocab/unit/PetaA")
    NanoSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/NanoSV-PER-MIN")
    OZ_TROY = URIRef("http://qudt.org/vocab/unit/OZ_TROY")
    PebiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M2")
    BTU_IT_PER_SEC_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC-FT2-DEG_R")
    NUM_PER_HR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HR")
    MDOLLAR_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MDOLLAR-PER-FLIGHT")
    M3_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-BAR")
    S_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/S-M2-PER-MOL")
    KiloGM_F_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-SEC")
    PERCENT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_US")
    FT2_PER_HR = URIRef("http://qudt.org/vocab/unit/FT2-PER-HR")
    GA_Charriere = URIRef("http://qudt.org/vocab/unit/GA_Charriere")
    BTU_TH_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-LB-DEG_R")
    LB_PER_HR_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-PSI")
    GigaBQ = URIRef("http://qudt.org/vocab/unit/GigaBQ")
    DeciC = URIRef("http://qudt.org/vocab/unit/DeciC")
    BTU_IT_IN_PER_FT2_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-FT2-SEC-DEG_F")
    KiloGAUSS = URIRef("http://qudt.org/vocab/unit/KiloGAUSS")
    C_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/C-M2-PER-KiloGM")
    GI_US = URIRef("http://qudt.org/vocab/unit/GI_US")
    BTU_IT_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-IN2-SEC")
    ExaBYTE = URIRef("http://qudt.org/vocab/unit/ExaBYTE")
    YR_TROPICAL = URIRef("http://qudt.org/vocab/unit/YR_TROPICAL")
    MilliGRAY = URIRef("http://qudt.org/vocab/unit/MilliGRAY")
    A_PER_CentiM = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM")
    DEGREE_BRIX = URIRef("http://qudt.org/vocab/unit/DEGREE_BRIX")
    BTU_TH_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR-FT2-DEG_F")
    PicoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-KiloGM")
    KiloLB_F = URIRef("http://qudt.org/vocab/unit/KiloLB_F")
    BTU_IT_IN_PER_SEC_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-SEC-FT2-DEG_F")
    PERCENT_PER_M = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-M")
    CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM-SEC-DEG_C")
    BTU_IT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MIN")
    PK_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_UK-PER-SEC")
    GM_PER_MIN = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN")
    FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC")
    DEGREE_PLATO = URIRef("http://qudt.org/vocab/unit/DEGREE_PLATO")
    PSI_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-M3-PER-SEC")
    MicroH_PER_M = URIRef("http://qudt.org/vocab/unit/MicroH-PER-M")
    NanoMOL_PER_MicroGM_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroGM-HR")
    MilliRAD_R_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliRAD_R-PER-HR")
    KiloGM_F_M = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M")
    SEC_PER_M3_RAD = URIRef("http://qudt.org/vocab/unit/SEC-PER-M3-RAD")
    L_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-DAY-BAR")
    M3_PER_C = URIRef("http://qudt.org/vocab/unit/M3-PER-C")
    FARAD_Stat = URIRef("http://qudt.org/vocab/unit/FARAD_Stat")
    FT3_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT3-PER-PSI")
    GM_PER_L_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-L-POISE")
    KiloGM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-K")
    M_SEC2 = URIRef("http://qudt.org/vocab/unit/M-SEC2")
    FT_HR_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_US")
    MegaGM = URIRef("http://qudt.org/vocab/unit/MegaGM")
    DEG_F_HR_FT2_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH")
    HK = URIRef("http://qudt.org/vocab/unit/HK")
    V_PER_SEC = URIRef("http://qudt.org/vocab/unit/V-PER-SEC")
    MilliM_H2O = URIRef("http://qudt.org/vocab/unit/MilliM_H2O")
    GM_Nitrogen_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM_Nitrogen-PER-M2-DAY")
    MicroGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-HR")
    FT_LB_F_PER_MIN = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-MIN")
    PER_M_NanoM = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM")
    MegaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-SEC")
    PlanckEnergy = URIRef("http://qudt.org/vocab/unit/PlanckEnergy")
    Denier = URIRef("http://qudt.org/vocab/unit/Denier")
    M_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-SEC")
    ST_PER_BAR = URIRef("http://qudt.org/vocab/unit/ST-PER-BAR")
    M_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/M-PER-DEG_C-M")
    ATM_M3_PER_MOL = URIRef("http://qudt.org/vocab/unit/ATM-M3-PER-MOL")
    MicroGM_PER_L = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-L")
    FemtoJ = URIRef("http://qudt.org/vocab/unit/FemtoJ")
    SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SEC-PER-FT2")
    DEG_F_PER_K = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-K")
    FT_SEC_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-SEC-PER-GAL_UK")
    KiloJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloGM")
    MilliGM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M")
    CORD = URIRef("http://qudt.org/vocab/unit/CORD")
    MilliL_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC-K")
    L_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/L-PER-MicroMOL")
    PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PER-KiloGM")
    FARAD_PER_M = URIRef("http://qudt.org/vocab/unit/FARAD-PER-M")
    KIP_F = URIRef("http://qudt.org/vocab/unit/KIP_F")
    PSI_PER_IN = URIRef("http://qudt.org/vocab/unit/PSI-PER-IN")
    KiloBAR = URIRef("http://qudt.org/vocab/unit/KiloBAR")
    KiloGM_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-PA")
    PPTH_PER_HR = URIRef("http://qudt.org/vocab/unit/PPTH-PER-HR")
    CentiM4 = URIRef("http://qudt.org/vocab/unit/CentiM4")
    KiloBD = URIRef("http://qudt.org/vocab/unit/KiloBD")
    GibiBYTE = URIRef("http://qudt.org/vocab/unit/GibiBYTE")
    CAL_TH_PER_GM = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM")
    KiloGM_PER_SEC_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-M2")
    MegaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MegaV-A_Reactive")
    M_PER_BAR = URIRef("http://qudt.org/vocab/unit/M-PER-BAR")
    OZ_FT = URIRef("http://qudt.org/vocab/unit/OZ-FT")
    KiloM3_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM3-PER-SEC2")
    DEATHS_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-KiloINDIV-YR")
    N_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM2")
    BARAD = URIRef("http://qudt.org/vocab/unit/BARAD")
    A_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/A-PER-KiloGM")
    LM_SEC = URIRef("http://qudt.org/vocab/unit/LM-SEC")
    HectoGM = URIRef("http://qudt.org/vocab/unit/HectoGM")
    MicroM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MicroM3-PER-M3")
    IN_PER_YR = URIRef("http://qudt.org/vocab/unit/IN-PER-YR")
    W_PER_M2_M = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M")
    ZettaC = URIRef("http://qudt.org/vocab/unit/ZettaC")
    DeciM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-KiloGM")
    DeciBAR = URIRef("http://qudt.org/vocab/unit/DeciBAR")
    MicroMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L-HR")
    GAL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-HR")
    B = URIRef("http://qudt.org/vocab/unit/B")
    DeciM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-M3")
    RAD_M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-MOL")
    L_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/L-PER-SEC-BAR")
    M2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2")
    GI_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_US-PER-DAY")
    CentiM3_PER_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-K")
    J_PER_KiloGM_K_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-M3")
    W_PER_K = URIRef("http://qudt.org/vocab/unit/W-PER-K")
    BTU_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-MIN")
    PER_MIN = URIRef("http://qudt.org/vocab/unit/PER-MIN")
    M_PER_RAD = URIRef("http://qudt.org/vocab/unit/M-PER-RAD")
    M2_PER_SEC2_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC2-K")
    MilliV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MilliV-A_Reactive")
    GigaC_PER_M3 = URIRef("http://qudt.org/vocab/unit/GigaC-PER-M3")
    MI_UK3 = URIRef("http://qudt.org/vocab/unit/MI_UK3")
    A2_SEC = URIRef("http://qudt.org/vocab/unit/A2-SEC")
    MIL = URIRef("http://qudt.org/vocab/unit/MIL")
    PERCENT_SEC_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-GAL_US")
    PER_SEC_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-SR")
    N_M2 = URIRef("http://qudt.org/vocab/unit/N-M2")
    A_HR_PER_M2 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M2")
    AttoSEC = URIRef("http://qudt.org/vocab/unit/AttoSEC")
    T_Ab = URIRef("http://qudt.org/vocab/unit/T_Ab")
    IN4 = URIRef("http://qudt.org/vocab/unit/IN4")
    AttoJ_SEC = URIRef("http://qudt.org/vocab/unit/AttoJ-SEC")
    MicroN_M = URIRef("http://qudt.org/vocab/unit/MicroN-M")
    PicoM = URIRef("http://qudt.org/vocab/unit/PicoM")
    J_PER_K = URIRef("http://qudt.org/vocab/unit/J-PER-K")
    GR = URIRef("http://qudt.org/vocab/unit/GR")
    PicoPA = URIRef("http://qudt.org/vocab/unit/PicoPA")
    GI_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GI_US-PER-MIN")
    PDL_PER_IN = URIRef("http://qudt.org/vocab/unit/PDL-PER-IN")
    M_PER_PA = URIRef("http://qudt.org/vocab/unit/M-PER-PA")
    GI_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-DAY")
    KiloN_M = URIRef("http://qudt.org/vocab/unit/KiloN-M")
    GigaV = URIRef("http://qudt.org/vocab/unit/GigaV")
    KiloL = URIRef("http://qudt.org/vocab/unit/KiloL")
    DEG_F = URIRef("http://qudt.org/vocab/unit/DEG_F")
    PicoC = URIRef("http://qudt.org/vocab/unit/PicoC")
    NUM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2-DAY")
    DEG_C2_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C2-PER-SEC")
    BU_US = URIRef("http://qudt.org/vocab/unit/BU_US")
    PERCENT_RH = URIRef("http://qudt.org/vocab/unit/PERCENT_RH")
    NanoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L")
    TON_Metric_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY-BAR")
    MicroFARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-KiloM")
    MicroFARAD = URIRef("http://qudt.org/vocab/unit/MicroFARAD")
    DAY_Sidereal = URIRef("http://qudt.org/vocab/unit/DAY_Sidereal")
    NAT_PER_SEC = URIRef("http://qudt.org/vocab/unit/NAT-PER-SEC")
    M3_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/M3-PER-HA-YR")
    KiloCAL_IT = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT")
    DeciM3_PER_DAY = URIRef("http://qudt.org/vocab/unit/DeciM3-PER-DAY")
    LB_HR_PER_GAL_US_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-FT3")
    BBL_UK_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-HR")
    OZ_FT_HR_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-HR-PER-IN3-LB")
    GM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-K")
    KiloV = URIRef("http://qudt.org/vocab/unit/KiloV")
    MicroV = URIRef("http://qudt.org/vocab/unit/MicroV")
    L_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/L-PER-KiloGM")
    TeraBQ = URIRef("http://qudt.org/vocab/unit/TeraBQ")
    LB_HR_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-IN3")
    V_A_HR = URIRef("http://qudt.org/vocab/unit/V-A-HR")
    NanoGM_PER_L = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-L")
    PER_YR = URIRef("http://qudt.org/vocab/unit/PER-YR")
    MilliGM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-POISE")
    GI_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-SEC")
    IN_H2O_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_60DEG_F")
    LB_F_PER_YD = URIRef("http://qudt.org/vocab/unit/LB_F-PER-YD")
    LB_PER_YD3 = URIRef("http://qudt.org/vocab/unit/LB-PER-YD3")
    DeciB_MilliW = URIRef("http://qudt.org/vocab/unit/DeciB-MilliW")
    PER_L = URIRef("http://qudt.org/vocab/unit/PER-L")
    TON_Metric = URIRef("http://qudt.org/vocab/unit/TON_Metric")
    MilliGM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-MIN-K")
    MicroMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-KiloGM")
    KiloA = URIRef("http://qudt.org/vocab/unit/KiloA")
    H_Stat = URIRef("http://qudt.org/vocab/unit/H_Stat")
    MicroSV_PER_HR = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-HR")
    PERCENT_PER_KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-KiloCount")
    KiloMOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-M3-K")
    MOL_LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-MIN")
    RAD_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/RAD-M2-PER-KiloGM")
    ERG_PER_G = URIRef("http://qudt.org/vocab/unit/ERG-PER-G")
    PER_PicoM = URIRef("http://qudt.org/vocab/unit/PER-PicoM")
    NanoM_PER_CentiM_MegaPA = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-MegaPA")
    PER_V_A_SEC = URIRef("http://qudt.org/vocab/unit/PER-V-A-SEC")
    EV_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/EV-M2-PER-KiloGM")
    Megahertz_KiloM = URIRef("http://qudt.org/vocab/unit/Megahertz-KiloM")
    RHE = URIRef("http://qudt.org/vocab/unit/RHE")
    Ci = URIRef("http://qudt.org/vocab/unit/Ci")
    MilliN = URIRef("http://qudt.org/vocab/unit/MilliN")
    MOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/MOL-PER-MIN")
    MegaHZ = URIRef("http://qudt.org/vocab/unit/MegaHZ")
    MilliM4 = URIRef("http://qudt.org/vocab/unit/MilliM4")
    PERCENT_PER_K = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-K")
    W_PER_SR = URIRef("http://qudt.org/vocab/unit/W-PER-SR")
    GM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM2")
    AMU = URIRef("http://qudt.org/vocab/unit/AMU")
    DYN_M = URIRef("http://qudt.org/vocab/unit/DYN-M")
    TON_SHIPPING_US = URIRef("http://qudt.org/vocab/unit/TON_SHIPPING_US")
    J_PER_M4 = URIRef("http://qudt.org/vocab/unit/J-PER-M4")
    LB_F_IN_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-IN-PER-IN")
    GigaHZ = URIRef("http://qudt.org/vocab/unit/GigaHZ")
    PER_WB = URIRef("http://qudt.org/vocab/unit/PER-WB")
    MOL_PER_GM_HR = URIRef("http://qudt.org/vocab/unit/MOL-PER-GM-HR")
    KiloJ = URIRef("http://qudt.org/vocab/unit/KiloJ")
    MegaOHM = URIRef("http://qudt.org/vocab/unit/MegaOHM")
    PicoW_PER_M2 = URIRef("http://qudt.org/vocab/unit/PicoW-PER-M2")
    KiloGM_CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-CentiM-PER-SEC")
    S_PER_CentiM = URIRef("http://qudt.org/vocab/unit/S-PER-CentiM")
    LB_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-HR-DEG_F")
    KiloGM_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-SEC")
    DeciB_PER_KiloM = URIRef("http://qudt.org/vocab/unit/DeciB-PER-KiloM")
    DEGREE_BAUME = URIRef("http://qudt.org/vocab/unit/DEGREE_BAUME")
    M3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/M3-PER-MOL-SEC")
    LB_F_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-IN2")
    KiloC_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloC-PER-M3")
    PicoGM_PER_GM = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-GM")
    MilliBQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-KiloGM")
    GM = URIRef("http://qudt.org/vocab/unit/GM")
    TON_Metric_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-DAY")
    PER_NanoM = URIRef("http://qudt.org/vocab/unit/PER-NanoM")
    C_Ab_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/C_Ab-PER-CentiM2")
    KiloN_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M2")
    OHM_PER_M = URIRef("http://qudt.org/vocab/unit/OHM-PER-M")
    OZ_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_UK")
    N_M_PER_DEG = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG")
    BYTE = URIRef("http://qudt.org/vocab/unit/BYTE")
    PERCENT_MIN_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-YD3")
    TeraA = URIRef("http://qudt.org/vocab/unit/TeraA")
    MO_Synodic = URIRef("http://qudt.org/vocab/unit/MO_Synodic")
    PicoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-M2-DAY")
    IN_HG_60DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_60DEG_F")
    PER_M_SR = URIRef("http://qudt.org/vocab/unit/PER-M-SR")
    DeciB_M = URIRef("http://qudt.org/vocab/unit/DeciB_M")
    GM_PER_GM = URIRef("http://qudt.org/vocab/unit/GM-PER-GM")
    BARYE = URIRef("http://qudt.org/vocab/unit/BARYE")
    PERCENT_PER_DecaK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaK")
    MilliV_A = URIRef("http://qudt.org/vocab/unit/MilliV-A")
    DEG_C_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-SEC")
    DeciBAR_PER_YR = URIRef("http://qudt.org/vocab/unit/DeciBAR-PER-YR")
    W_PER_M_K = URIRef("http://qudt.org/vocab/unit/W-PER-M-K")
    KiloCi = URIRef("http://qudt.org/vocab/unit/KiloCi")
    KiloPA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/KiloPA-PER-MilliM")
    GM_SEC_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-M3")
    ERG_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2-SEC")
    BTU_MEAN = URIRef("http://qudt.org/vocab/unit/BTU_MEAN")
    BTU_TH_IN_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-IN-PER-FT2-HR-DEG_F")
    KiloCAL_PER_MOL = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-MOL")
    TON_Metric_PER_HR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR")
    M3_PER_M3 = URIRef("http://qudt.org/vocab/unit/M3-PER-M3")
    DEG_R_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-HR")
    NanoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/NanoV-A_Reactive")
    MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliPA-SEC")
    FT3_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT3-PER-DAY")
    MilliM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliM2-PER-SEC")
    M3_PER_HR_K = URIRef("http://qudt.org/vocab/unit/M3-PER-HR-K")
    NUM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-KiloM2")
    BTU_IT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-DEG_F")
    DecaC = URIRef("http://qudt.org/vocab/unit/DecaC")
    PicoMOL_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-DAY")
    TON_SHORT = URIRef("http://qudt.org/vocab/unit/TON_SHORT")
    PicoW_PER_CentiM2_L = URIRef("http://qudt.org/vocab/unit/PicoW-PER-CentiM2-L")
    TeraV = URIRef("http://qudt.org/vocab/unit/TeraV")
    KiloBTU_TH = URIRef("http://qudt.org/vocab/unit/KiloBTU_TH")
    PPM = URIRef("http://qudt.org/vocab/unit/PPM")
    MicroRAD = URIRef("http://qudt.org/vocab/unit/MicroRAD")
    MegaS = URIRef("http://qudt.org/vocab/unit/MegaS")
    ROD = URIRef("http://qudt.org/vocab/unit/ROD")
    GM_PER_MOL = URIRef("http://qudt.org/vocab/unit/GM-PER-MOL")
    PERCENT_PER_HR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HR")
    NanoV_A = URIRef("http://qudt.org/vocab/unit/NanoV-A")
    GM_PER_MilliL_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-K")
    FemtoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-KiloGM")
    Da = URIRef("http://qudt.org/vocab/unit/Da")
    PER_WK = URIRef("http://qudt.org/vocab/unit/PER-WK")
    L_PER_L = URIRef("http://qudt.org/vocab/unit/L-PER-L")
    KiloGM_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-PA")
    LB_PER_LB = URIRef("http://qudt.org/vocab/unit/LB-PER-LB")
    N_SEC = URIRef("http://qudt.org/vocab/unit/N-SEC")
    PERMEABILITY_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_REL")
    MilliGRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-MIN")
    MicroGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M2-DAY")
    CM_H2O = URIRef("http://qudt.org/vocab/unit/CM_H2O")
    K_PER_M = URIRef("http://qudt.org/vocab/unit/K-PER-M")
    L_PER_HR = URIRef("http://qudt.org/vocab/unit/L-PER-HR")
    PicoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-L-HR")
    GI_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/GI_UK-PER-HR")
    LB_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-YD3")
    PicoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/PicoMOL-PER-KiloGM")
    B_PER_M = URIRef("http://qudt.org/vocab/unit/B-PER-M")
    DPI = URIRef("http://qudt.org/vocab/unit/DPI")
    KiloJ_PER_KiloV = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-KiloV")
    SLUG = URIRef("http://qudt.org/vocab/unit/SLUG")
    RAD_R = URIRef("http://qudt.org/vocab/unit/RAD_R")
    LB_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_UK")
    OZ_MIN_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-YD3")
    IN_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC2")
    PA_M = URIRef("http://qudt.org/vocab/unit/PA-M")
    J_M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/J-M2-PER-KiloGM")
    MicroGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-DeciL")
    N_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/N-PER-KiloGM")
    M2_SEC_PER_RAD = URIRef("http://qudt.org/vocab/unit/M2-SEC-PER-RAD")
    MilliM = URIRef("http://qudt.org/vocab/unit/MilliM")
    NUM_PER_L = URIRef("http://qudt.org/vocab/unit/NUM-PER-L")
    M2_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M2-PER-V-SEC")
    A_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM2")
    PER_K = URIRef("http://qudt.org/vocab/unit/PER-K")
    PERM_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_0DEG_C")
    N_CentiM = URIRef("http://qudt.org/vocab/unit/N-CentiM")
    K_PER_T = URIRef("http://qudt.org/vocab/unit/K-PER-T")
    CentiM_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC")
    A_PER_RAD = URIRef("http://qudt.org/vocab/unit/A-PER-RAD")
    PINT = URIRef("http://qudt.org/vocab/unit/PINT")
    SCM = URIRef("http://qudt.org/vocab/unit/SCM")
    CentiBAR = URIRef("http://qudt.org/vocab/unit/CentiBAR")
    PER_DEG_F = URIRef("http://qudt.org/vocab/unit/PER-DEG_F")
    KiloBAUD = URIRef("http://qudt.org/vocab/unit/KiloBAUD")
    NanoH_PER_M = URIRef("http://qudt.org/vocab/unit/NanoH-PER-M")
    DEG_F_SEC_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-SEC-PER-BTU_IT")
    EarthMass = URIRef("http://qudt.org/vocab/unit/EarthMass")
    J_PER_GM_K = URIRef("http://qudt.org/vocab/unit/J-PER-GM-K")
    FT2_HR_DEG_F_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F-PER-BTU_IT")
    CAL_TH_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-GM-DEG_C")
    BTU_IT_PER_MOL_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL-DEG_F")
    CentiPOISE = URIRef("http://qudt.org/vocab/unit/CentiPOISE")
    FemtoFARAD = URIRef("http://qudt.org/vocab/unit/FemtoFARAD")
    PA_PER_MIN = URIRef("http://qudt.org/vocab/unit/PA-PER-MIN")
    TonEnergy = URIRef("http://qudt.org/vocab/unit/TonEnergy")
    MicroGM_PER_IN2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-IN2")
    MIN_Angle = URIRef("http://qudt.org/vocab/unit/MIN_Angle")
    MegaEV = URIRef("http://qudt.org/vocab/unit/MegaEV")
    IN_PDL = URIRef("http://qudt.org/vocab/unit/IN-PDL")
    SLUG_PER_FT = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT")
    NUM_PER_HA = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA")
    SEC2 = URIRef("http://qudt.org/vocab/unit/SEC2")
    MicroW_PER_M2 = URIRef("http://qudt.org/vocab/unit/MicroW-PER-M2")
    KiloJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-SEC")
    W_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-PER-KiloGM")
    PetaHZ = URIRef("http://qudt.org/vocab/unit/PetaHZ")
    KiloBQ = URIRef("http://qudt.org/vocab/unit/KiloBQ")
    TON_SHORT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-DEG_F")
    GALILEO = URIRef("http://qudt.org/vocab/unit/GALILEO")
    KiloGM_PER_KiloM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloM2")
    CentiM3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MIN-K")
    HP_Brake = URIRef("http://qudt.org/vocab/unit/HP_Brake")
    MOL_PER_M3_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-K")
    OZ_MIN_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN3-GAL_US")
    MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/MOL_LB-DEG_F")
    KiloCAL_PER_GM_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM-DEG_C")
    W_HR_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/W-HR-PER-KiloGM")
    PER_SEC = URIRef("http://qudt.org/vocab/unit/PER-SEC")
    ExbiBIT_PER_M2 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M2")
    KiloBTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-FT2")
    MilliBAR_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliBAR-L-PER-SEC")
    CentiM3_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-SEC-K")
    PER_GM = URIRef("http://qudt.org/vocab/unit/PER-GM")
    A_Ab_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Ab-CentiM2")
    TON_US = URIRef("http://qudt.org/vocab/unit/TON_US")
    KiloGM_PER_M_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-SEC")
    STILB = URIRef("http://qudt.org/vocab/unit/STILB")
    MicroPOISE = URIRef("http://qudt.org/vocab/unit/MicroPOISE")
    N_PER_A = URIRef("http://qudt.org/vocab/unit/N-PER-A")
    MI = URIRef("http://qudt.org/vocab/unit/MI")
    KiloGM_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-M-PER-SEC")
    PERCENT_MIN_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-CentiM3")
    BTU_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-SEC")
    KiloGM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN-BAR")
    MilliGM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-CentiM3")
    MilliBAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-BAR")
    SUSCEPTIBILITY_ELEC = URIRef("http://qudt.org/vocab/unit/SUSCEPTIBILITY_ELEC")
    NanoGM = URIRef("http://qudt.org/vocab/unit/NanoGM")
    BTU_TH_PER_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_R")
    GON = URIRef("http://qudt.org/vocab/unit/GON")
    MilliGM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-CentiPOISE")
    PER_GigaEV2 = URIRef("http://qudt.org/vocab/unit/PER-GigaEV2")
    GM_PER_MilliM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM-BAR")
    BTU_IT_PER_HR_FT2_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_R")
    NUM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NUM-PER-MicroL")
    NanoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MilliL")
    KiloA_PER_K = URIRef("http://qudt.org/vocab/unit/KiloA-PER-K")
    PER_HR = URIRef("http://qudt.org/vocab/unit/PER-HR")
    HectoL = URIRef("http://qudt.org/vocab/unit/HectoL")
    MilliGM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-CentiM3")
    M2_PER_K = URIRef("http://qudt.org/vocab/unit/M2-PER-K")
    BTU_TH_FT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-FT-PER-HR-FT2-DEG_F")
    PDL = URIRef("http://qudt.org/vocab/unit/PDL")
    KY = URIRef("http://qudt.org/vocab/unit/KY")
    M2_PER_GM = URIRef("http://qudt.org/vocab/unit/M2-PER-GM")
    GM_PER_M3_CentiPOISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-CentiPOISE")
    BTU_IT_PER_LB_DEG_R = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-LB-DEG_R")
    V_Ab_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V_Ab-PER-CentiM")
    MilliV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliV-PER-MIN")
    OHM_Ab = URIRef("http://qudt.org/vocab/unit/OHM_Ab")
    K_M_PER_W = URIRef("http://qudt.org/vocab/unit/K-M-PER-W")
    DEG_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC2")
    KibiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M")
    PERCENT_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-L")
    TONNE_PER_MIN = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN")
    DEG_F_HR_FT2_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_IT")
    DeciM3 = URIRef("http://qudt.org/vocab/unit/DeciM3")
    KiloCAL_TH_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloCAL_TH-PER-MIN")
    PINT_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_UK-PER-MIN")
    MicroH = URIRef("http://qudt.org/vocab/unit/MicroH")
    N_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M3")
    NanoGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M3")
    PicoGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/PicoGM-PER-MilliL")
    PSU = URIRef("http://qudt.org/vocab/unit/PSU")
    NanoH = URIRef("http://qudt.org/vocab/unit/NanoH")
    PicoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/PicoKAT-PER-L")
    NanoMOL_PER_L_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-L-HR")
    FARAD_Ab = URIRef("http://qudt.org/vocab/unit/FARAD_Ab")
    GAUGE_FR = URIRef("http://qudt.org/vocab/unit/GAUGE_FR")
    BTU_IT_PER_MOL_LB_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-MOL_LB-DEG_F")
    KiloGM_F_M_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM_F-M-PER-CentiM2")
    BU_UK_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-MIN")
    MX = URIRef("http://qudt.org/vocab/unit/MX")
    V_PER_K = URIRef("http://qudt.org/vocab/unit/V-PER-K")
    MilliDARCY = URIRef("http://qudt.org/vocab/unit/MilliDARCY")
    PER_J = URIRef("http://qudt.org/vocab/unit/PER-J")
    TONNE_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-K")
    M2_PER_M = URIRef("http://qudt.org/vocab/unit/M2-PER-M")
    CentiN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/CentiN-M-PER-M2")
    CentiM_PER_KiloYR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-KiloYR")
    TON_SHORT_PER_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/TON_SHORT-PER-HR-DEG_F")
    OZ_VOL_UK = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK")
    PlanckDensity = URIRef("http://qudt.org/vocab/unit/PlanckDensity")
    LB_MIN_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK2")
    LB_F_FT_PER_IN = URIRef("http://qudt.org/vocab/unit/LB_F-FT-PER-IN")
    J_PER_HR = URIRef("http://qudt.org/vocab/unit/J-PER-HR")
    THERM_EC = URIRef("http://qudt.org/vocab/unit/THERM_EC")
    ERG_PER_SEC = URIRef("http://qudt.org/vocab/unit/ERG-PER-SEC")
    M3_PER_SEC_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-PA")
    MilliGM_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-GM")
    MilliGAL = URIRef("http://qudt.org/vocab/unit/MilliGAL")
    TON_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_US-PER-DAY")
    MegaW_HR = URIRef("http://qudt.org/vocab/unit/MegaW-HR")
    MilliM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliM-PER-HR")
    LB_PER_FT3_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-PSI")
    MilliN_M_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliN-M-PER-M2")
    OCT = URIRef("http://qudt.org/vocab/unit/OCT")
    M3_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-SEC-BAR")
    M6 = URIRef("http://qudt.org/vocab/unit/M6")
    MilliN_M = URIRef("http://qudt.org/vocab/unit/MilliN-M")
    CentiM3_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-GM")
    YR = URIRef("http://qudt.org/vocab/unit/YR")
    SEC_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/SEC-PER-KiloGM")
    CentiPOISE_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-BAR")
    TON_Metric_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN-K")
    OZ_F_IN = URIRef("http://qudt.org/vocab/unit/OZ_F-IN")
    QT_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-SEC")
    MegaBAUD = URIRef("http://qudt.org/vocab/unit/MegaBAUD")
    DeciGM = URIRef("http://qudt.org/vocab/unit/DeciGM")
    FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-HR-DEG_F")
    M2_PER_SR_J = URIRef("http://qudt.org/vocab/unit/M2-PER-SR-J")
    MegaEV_PER_CentiM = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-CentiM")
    HectoPA_PER_M = URIRef("http://qudt.org/vocab/unit/HectoPA-PER-M")
    GM_PER_MilliM = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM")
    CentiMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-KiloGM")
    DeciTON_Metric = URIRef("http://qudt.org/vocab/unit/DeciTON_Metric")
    LB_HR_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-GAL_US")
    PCA = URIRef("http://qudt.org/vocab/unit/PCA")
    LB_PER_FT3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-FT3-DEG_F")
    M2_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/M2-PER-HA-YR")
    KiloPA = URIRef("http://qudt.org/vocab/unit/KiloPA")
    MicroBQ = URIRef("http://qudt.org/vocab/unit/MicroBQ")
    PER_MilliSEC = URIRef("http://qudt.org/vocab/unit/PER-MilliSEC")
    PetaBYTE = URIRef("http://qudt.org/vocab/unit/PetaBYTE")
    M_H2O = URIRef("http://qudt.org/vocab/unit/M_H2O")
    BAN = URIRef("http://qudt.org/vocab/unit/BAN")
    TeraHZ = URIRef("http://qudt.org/vocab/unit/TeraHZ")
    HeartBeat = URIRef("http://qudt.org/vocab/unit/HeartBeat")
    MilliM3_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-KiloGM")
    CentiGRAY = URIRef("http://qudt.org/vocab/unit/CentiGRAY")
    LB_MIN_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-IN3")
    PA2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA2-PER-SEC2")
    SV_PER_SEC = URIRef("http://qudt.org/vocab/unit/SV-PER-SEC")
    BBL_UK_PET_PER_MIN = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-MIN")
    RAD_PER_HR = URIRef("http://qudt.org/vocab/unit/RAD-PER-HR")
    MilliBAR_PER_K = URIRef("http://qudt.org/vocab/unit/MilliBAR-PER-K")
    CentiM2_PER_SEC = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SEC")
    KiloGM_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3")
    M_KiloGM = URIRef("http://qudt.org/vocab/unit/M-KiloGM")
    M3_PER_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-BAR")
    GM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-L-MilliPA-SEC")
    KiloN_M_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-M-PER-M")
    A_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/A-HR-PER-M3")
    HR_FT2 = URIRef("http://qudt.org/vocab/unit/HR-FT2")
    NUM_PER_M = URIRef("http://qudt.org/vocab/unit/NUM-PER-M")
    PicoGM = URIRef("http://qudt.org/vocab/unit/PicoGM")
    MilliJ_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-GM")
    V_PER_V = URIRef("http://qudt.org/vocab/unit/V-PER-V")
    NanoMOL_PER_MicroMOL_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL-DAY")
    GigaV_A = URIRef("http://qudt.org/vocab/unit/GigaV-A")
    MicroSEC = URIRef("http://qudt.org/vocab/unit/MicroSEC")
    NanoKAT_PER_L = URIRef("http://qudt.org/vocab/unit/NanoKAT-PER-L")
    LB_SEC_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US2")
    BQ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/BQ-PER-KiloGM")
    GRAD = URIRef("http://qudt.org/vocab/unit/GRAD")
    N_M_PER_A = URIRef("http://qudt.org/vocab/unit/N-M-PER-A")
    PlanckFrequency_Ang = URIRef("http://qudt.org/vocab/unit/PlanckFrequency_Ang")
    MicroN = URIRef("http://qudt.org/vocab/unit/MicroN")
    N_M2_PER_A = URIRef("http://qudt.org/vocab/unit/N-M2-PER-A")
    SCM_PER_HR = URIRef("http://qudt.org/vocab/unit/SCM-PER-HR")
    BAR = URIRef("http://qudt.org/vocab/unit/BAR")
    CAL_TH = URIRef("http://qudt.org/vocab/unit/CAL_TH")
    PlanckLength = URIRef("http://qudt.org/vocab/unit/PlanckLength")
    DEGREE_TWADDELL = URIRef("http://qudt.org/vocab/unit/DEGREE_TWADDELL")
    LB_M = URIRef("http://qudt.org/vocab/unit/LB_M")
    TON_Metric_PER_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-BAR")
    ATM_PER_M = URIRef("http://qudt.org/vocab/unit/ATM-PER-M")
    J_PER_KiloGM_K_PA = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K-PA")
    A_MIN = URIRef("http://qudt.org/vocab/unit/A-MIN")
    A_M2 = URIRef("http://qudt.org/vocab/unit/A-M2")
    MegaDOLLAR_US_PER_FLIGHT = URIRef("http://qudt.org/vocab/unit/MegaDOLLAR_US-PER-FLIGHT")
    PERCENT_HR_PER_L = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-L")
    LB_HR_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT6")
    M2_HZ2 = URIRef("http://qudt.org/vocab/unit/M2-HZ2")
    PER_T_M = URIRef("http://qudt.org/vocab/unit/PER-T-M")
    KiloN_M2 = URIRef("http://qudt.org/vocab/unit/KiloN-M2")
    WK = URIRef("http://qudt.org/vocab/unit/WK")
    GM_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR-BAR")
    KiloGM_PER_GigaJ = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-GigaJ")
    PSI_PER_PSI = URIRef("http://qudt.org/vocab/unit/PSI-PER-PSI")
    PK_US_DRY_PER_SEC = URIRef("http://qudt.org/vocab/unit/PK_US_DRY-PER-SEC")
    PERCENT_MIN_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_US")
    CentiM = URIRef("http://qudt.org/vocab/unit/CentiM")
    PER_M2 = URIRef("http://qudt.org/vocab/unit/PER-M2")
    DeciL_PER_GM = URIRef("http://qudt.org/vocab/unit/DeciL-PER-GM")
    LB_PER_IN3_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-IN3-DEG_F")
    MOL_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/MOL-PER-DeciM3")
    GigaV_A_Reactive = URIRef("http://qudt.org/vocab/unit/GigaV-A_Reactive")
    MO_MeanJulian = URIRef("http://qudt.org/vocab/unit/MO_MeanJulian")
    MegaTON = URIRef("http://qudt.org/vocab/unit/MegaTON")
    NanoMOL_PER_CentiM3_HR = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-CentiM3-HR")
    KiloM = URIRef("http://qudt.org/vocab/unit/KiloM")
    M_PER_K = URIRef("http://qudt.org/vocab/unit/M-PER-K")
    MegaHZ_M = URIRef("http://qudt.org/vocab/unit/MegaHZ-M")
    PebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M")
    GM_PER_HR = URIRef("http://qudt.org/vocab/unit/GM-PER-HR")
    KiloBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/KiloBYTE-PER-SEC")
    MOL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-SEC")
    KiloM_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloM-PER-HR")
    LunarMass = URIRef("http://qudt.org/vocab/unit/LunarMass")
    A_Stat_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A_Stat-PER-CentiM2")
    MilliSV = URIRef("http://qudt.org/vocab/unit/MilliSV")
    LB_FT2_PER_GAL_UK_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_UK-LB_F-SEC")
    BU_US_DRY_PER_MIN = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-MIN")
    M2_PER_GM_DRY = URIRef("http://qudt.org/vocab/unit/M2-PER-GM_DRY")
    DEG_F_HR_FT2_PER_BTU_TH_IN = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-FT2-PER-BTU_TH-IN")
    MOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2")
    YD_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD-PER-DEG_F")
    ElementaryCharge = URIRef("http://qudt.org/vocab/unit/ElementaryCharge")
    R_PER_SEC = URIRef("http://qudt.org/vocab/unit/R-PER-SEC")
    GigaOHM_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-M")
    M3_PER_KiloGM_SEC2 = URIRef("http://qudt.org/vocab/unit/M3-PER-KiloGM-SEC2")
    MegaA = URIRef("http://qudt.org/vocab/unit/MegaA")
    MilliGM_PER_M2_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-HR")
    MicroG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroG-PER-CentiM2")
    NanoGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2")
    FT3_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT3-PER-SEC")
    Debye = URIRef("http://qudt.org/vocab/unit/Debye")
    PER_SEC_M2_SR = URIRef("http://qudt.org/vocab/unit/PER-SEC-M2-SR")
    KiloGM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M")
    FemtoGM = URIRef("http://qudt.org/vocab/unit/FemtoGM")
    CD_PER_LM = URIRef("http://qudt.org/vocab/unit/CD-PER-LM")
    PERCENT_PER_DecaCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DecaCount")
    OERSTED = URIRef("http://qudt.org/vocab/unit/OERSTED")
    KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2")
    MilliL_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-BAR")
    CAL_TH_PER_CentiM2_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM2-SEC")
    CentiN_M = URIRef("http://qudt.org/vocab/unit/CentiN-M")
    HP_Electric = URIRef("http://qudt.org/vocab/unit/HP_Electric")
    PebiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/PebiBIT-PER-M3")
    QT_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/QT_UK-PER-DAY")
    TeraV_A = URIRef("http://qudt.org/vocab/unit/TeraV-A")
    J_PER_M3 = URIRef("http://qudt.org/vocab/unit/J-PER-M3")
    AttoA = URIRef("http://qudt.org/vocab/unit/AttoA")
    PER_KiloM = URIRef("http://qudt.org/vocab/unit/PER-KiloM")
    MicroOHM_M = URIRef("http://qudt.org/vocab/unit/MicroOHM-M")
    FemtoSEC = URIRef("http://qudt.org/vocab/unit/FemtoSEC")
    LB_SEC_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-FT3")
    BU_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-SEC")
    MilliA_HR = URIRef("http://qudt.org/vocab/unit/MilliA-HR")
    PERCENT_FT2_PER_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-FT2-PER-LB_F-SEC")
    FemtoMOL_PER_L = URIRef("http://qudt.org/vocab/unit/FemtoMOL-PER-L")
    CentiM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/CentiM-PER-SEC-K")
    MI3 = URIRef("http://qudt.org/vocab/unit/MI3")
    KiloGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M2-SEC")
    MicroV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A-PER-K")
    GM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/GM-PER-KiloGM")
    DEG_R_PER_MIN = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-MIN")
    M2_PER_HA = URIRef("http://qudt.org/vocab/unit/M2-PER-HA")
    MilliS = URIRef("http://qudt.org/vocab/unit/MilliS")
    PFERDESTAERKE = URIRef("http://qudt.org/vocab/unit/PFERDESTAERKE")
    TeraOHM = URIRef("http://qudt.org/vocab/unit/TeraOHM")
    AttoC = URIRef("http://qudt.org/vocab/unit/AttoC")
    AC_FT = URIRef("http://qudt.org/vocab/unit/AC-FT")
    TONNE_PER_YR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-YR")
    TONNE_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-DAY-BAR")
    CentiM_PER_BAR = URIRef("http://qudt.org/vocab/unit/CentiM-PER-BAR")
    KiloV_A = URIRef("http://qudt.org/vocab/unit/KiloV-A")
    PlanckTime = URIRef("http://qudt.org/vocab/unit/PlanckTime")
    A_SEC2 = URIRef("http://qudt.org/vocab/unit/A-SEC2")
    KiloLB_F_FT_PER_A = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-A")
    G = URIRef("http://qudt.org/vocab/unit/G")
    FT2_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT2-PER-SEC")
    ERG_PER_CentiM = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM")
    ERG_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-PER-CentiM2")
    PERCENT_PER_POISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-POISE")
    CUP = URIRef("http://qudt.org/vocab/unit/CUP")
    PERMEABILITY_EM_REL = URIRef("http://qudt.org/vocab/unit/PERMEABILITY_EM_REL")
    KiloGM_PER_YR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-YR")
    LB_HR_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US-YD3")
    TON_Metric_PER_MIN = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-MIN")
    OZ_VOL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-SEC")
    BTU_TH_PER_FT3 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT3")
    TON_Metric_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-BAR")
    CentiPOISE_PER_K = URIRef("http://qudt.org/vocab/unit/CentiPOISE-PER-K")
    CH = URIRef("http://qudt.org/vocab/unit/CH")
    LB_PER_FT = URIRef("http://qudt.org/vocab/unit/LB-PER-FT")
    OHM_Stat = URIRef("http://qudt.org/vocab/unit/OHM_Stat")
    GM_MIN_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-CentiM3")
    KiloS_PER_M = URIRef("http://qudt.org/vocab/unit/KiloS-PER-M")
    THERM_US = URIRef("http://qudt.org/vocab/unit/THERM_US")
    PPTR_VOL = URIRef("http://qudt.org/vocab/unit/PPTR_VOL")
    KibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KibiBIT-PER-M3")
    KiloPA_A = URIRef("http://qudt.org/vocab/unit/KiloPA_A")
    ANGSTROM3 = URIRef("http://qudt.org/vocab/unit/ANGSTROM3")
    OZ_IN = URIRef("http://qudt.org/vocab/unit/OZ-IN")
    MegaTONNE = URIRef("http://qudt.org/vocab/unit/MegaTONNE")
    MilliBAR = URIRef("http://qudt.org/vocab/unit/MilliBAR")
    NanoMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-GM-SEC")
    LB_FT2_PER_GAL_US_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT2-PER-GAL_US-LB_F-SEC")
    YD3_PER_HR = URIRef("http://qudt.org/vocab/unit/YD3-PER-HR")
    ExbiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/ExbiBIT-PER-M3")
    R_man = URIRef("http://qudt.org/vocab/unit/R_man")
    MilliOHM_M = URIRef("http://qudt.org/vocab/unit/MilliOHM-M")
    BU_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_UK-PER-DAY")
    TSP = URIRef("http://qudt.org/vocab/unit/TSP")
    SEC_PER_M = URIRef("http://qudt.org/vocab/unit/SEC-PER-M")
    LB_PER_GAL = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL")
    TONNE_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-BAR")
    DEG_R_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG_R-PER-SEC")
    BTU_59DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_59DEG_F")
    CentiM_HG_0DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_HG_0DEG_C")
    MilliGM_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-HR")
    CHF_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/CHF-PER-KiloGM")
    EUR_PER_W_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-W-HR")
    NanoMOL_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-KiloGM")
    V_A_PER_K = URIRef("http://qudt.org/vocab/unit/V-A-PER-K")
    MilliA_PER_MilliM = URIRef("http://qudt.org/vocab/unit/MilliA-PER-MilliM")
    GM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-L")
    MilliG = URIRef("http://qudt.org/vocab/unit/MilliG")
    J_PER_T2 = URIRef("http://qudt.org/vocab/unit/J-PER-T2")
    LB_PER_SEC_PSI = URIRef("http://qudt.org/vocab/unit/LB-PER-SEC-PSI")
    OZ_FT_SEC_PER_IN3_LB = URIRef("http://qudt.org/vocab/unit/OZ-FT-SEC-PER-IN3-LB")
    BAR_PER_K = URIRef("http://qudt.org/vocab/unit/BAR-PER-K")
    LB_HR_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK-FT3")
    PERM_US = URIRef("http://qudt.org/vocab/unit/PERM_US")
    M3_PER_HA = URIRef("http://qudt.org/vocab/unit/M3-PER-HA")
    M_PA_PER_SEC = URIRef("http://qudt.org/vocab/unit/M-PA-PER-SEC")
    MilliM3_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-GM")
    NUM = URIRef("http://qudt.org/vocab/unit/NUM")
    TONNE_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3-K")
    M_SEC = URIRef("http://qudt.org/vocab/unit/M-SEC")
    TONNE_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MIN-BAR")
    M2_PER_MOL = URIRef("http://qudt.org/vocab/unit/M2-PER-MOL")
    CAL_20DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_20DEG_C")
    MilliR = URIRef("http://qudt.org/vocab/unit/MilliR")
    DEG_C_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_C-PER-BAR")
    CentiC = URIRef("http://qudt.org/vocab/unit/CentiC")
    KiloCAL_PER_GM = URIRef("http://qudt.org/vocab/unit/KiloCAL-PER-GM")
    NanoGM_PER_CentiM2_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-CentiM2-DAY")
    WB_M = URIRef("http://qudt.org/vocab/unit/WB-M")
    LB_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-PER-GAL_US")
    IN_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN-PER-SEC")
    MegaPA_M0pt5 = URIRef("http://qudt.org/vocab/unit/MegaPA-M0pt5")
    MOL_PER_L_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-K")
    ExaW = URIRef("http://qudt.org/vocab/unit/ExaW")
    PER_PlanckMass2 = URIRef("http://qudt.org/vocab/unit/PER-PlanckMass2")
    PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PER-PERCENT")
    YD_PER_HR = URIRef("http://qudt.org/vocab/unit/YD-PER-HR")
    MOL_PER_M2_SEC_M = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M")
    MegaOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-BAR")
    Kilo_FT3 = URIRef("http://qudt.org/vocab/unit/Kilo-FT3")
    QT_US_PER_HR = URIRef("http://qudt.org/vocab/unit/QT_US-PER-HR")
    PlanckMomentum = URIRef("http://qudt.org/vocab/unit/PlanckMomentum")
    PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/PER-M3-SEC")
    MicroS_PER_M = URIRef("http://qudt.org/vocab/unit/MicroS-PER-M")
    LB_HR_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-FT3-YD3")
    KiloT = URIRef("http://qudt.org/vocab/unit/KiloT")
    BTU_IT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-SEC")
    DEATHS_PER_1000000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000000I-YR")
    NanoMOL_PER_MicroMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-MicroMOL")
    CAL_IT_PER_SEC_CentiM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-SEC-CentiM-K")
    PERCENT_PER_WK = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-WK")
    A_PER_MilliM = URIRef("http://qudt.org/vocab/unit/A-PER-MilliM")
    M2_PER_KiloW = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloW")
    CARAT = URIRef("http://qudt.org/vocab/unit/CARAT")
    DEG_C_KiloGM_PER_M2 = URIRef("http://qudt.org/vocab/unit/DEG_C-KiloGM-PER-M2")
    N_M_PER_M_RAD = URIRef("http://qudt.org/vocab/unit/N-M-PER-M-RAD")
    PSI_L_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-L-PER-SEC")
    BBL_US_PET_PER_SEC = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-SEC")
    OZ_VOL_UK_PER_HR = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-HR")
    MilliW_PER_CentiM2_MicroM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-CentiM2-MicroM-SR")
    LB_F_SEC_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB_F-SEC-PER-FT2")
    PA_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PA-M3-PER-SEC")
    GI_UK = URIRef("http://qudt.org/vocab/unit/GI_UK")
    K_M2_PER_KiloGM_SEC = URIRef("http://qudt.org/vocab/unit/K-M2-PER-KiloGM-SEC")
    YD_PER_PSI = URIRef("http://qudt.org/vocab/unit/YD-PER-PSI")
    GM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-L-CentiM3")
    MilliKAT_PER_L = URIRef("http://qudt.org/vocab/unit/MilliKAT-PER-L")
    PERCENT_MIN_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-GAL_UK")
    LB_MIN_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-FT3")
    DeciB_PER_M = URIRef("http://qudt.org/vocab/unit/DeciB-PER-M")
    EV_PER_T = URIRef("http://qudt.org/vocab/unit/EV-PER-T")
    LB_SEC_PER_FT3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-GAL_UK")
    MicroL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroL-PER-L")
    OZ_PER_YD2 = URIRef("http://qudt.org/vocab/unit/OZ-PER-YD2")
    LB_PER_MIN_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN-DEG_F")
    MicroSV_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroSV-PER-SEC")
    PHON = URIRef("http://qudt.org/vocab/unit/PHON")
    KiloW = URIRef("http://qudt.org/vocab/unit/KiloW")
    NanoBQ = URIRef("http://qudt.org/vocab/unit/NanoBQ")
    OZ_VOL_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_UK-PER-DAY")
    KiloA_PER_M2 = URIRef("http://qudt.org/vocab/unit/KiloA-PER-M2")
    MI_US = URIRef("http://qudt.org/vocab/unit/MI_US")
    YR_Metrology = URIRef("http://qudt.org/vocab/unit/YR_Metrology")
    M2_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/M2-PER-KiloGM")
    MegaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBIT-PER-SEC")
    TON_UK_PER_DAY = URIRef("http://qudt.org/vocab/unit/TON_UK-PER-DAY")
    MilliGM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-DAY")
    LB_SEC_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-YD3")
    MilliMOL_PER_M2 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2")
    PERCENT_HR_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-YD3")
    POISE_PER_K = URIRef("http://qudt.org/vocab/unit/POISE-PER-K")
    GM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-MIN-PER-L-M3")
    GM_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliM2")
    PER_M_NanoM_SR = URIRef("http://qudt.org/vocab/unit/PER-M-NanoM-SR")
    MilliR_man = URIRef("http://qudt.org/vocab/unit/MilliR_man")
    GM_PER_M3_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-MilliPA-SEC")
    MicroGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MicroGRAY-PER-SEC")
    MilliL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliL-PER-L")
    LB_F_PER_IN2_SEC = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-SEC")
    SCF_PER_HR = URIRef("http://qudt.org/vocab/unit/SCF-PER-HR")
    FemtoL = URIRef("http://qudt.org/vocab/unit/FemtoL")
    KAT_PER_L = URIRef("http://qudt.org/vocab/unit/KAT-PER-L")
    M_PER_V_SEC = URIRef("http://qudt.org/vocab/unit/M-PER-V-SEC")
    KiloCAL = URIRef("http://qudt.org/vocab/unit/KiloCAL")
    KiloGM_K = URIRef("http://qudt.org/vocab/unit/KiloGM-K")
    FemtoGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/FemtoGM-PER-KiloGM")
    DecaM3 = URIRef("http://qudt.org/vocab/unit/DecaM3")
    DRAM_UK = URIRef("http://qudt.org/vocab/unit/DRAM_UK")
    MicroGAL_PER_M = URIRef("http://qudt.org/vocab/unit/MicroGAL-PER-M")
    M3_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-K")
    LB_MIN_PER_GAL_US_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US-YD3")
    GM_PER_MilliL_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MilliL-BAR")
    KiloTONNE = URIRef("http://qudt.org/vocab/unit/KiloTONNE")
    CAL_IT_PER_GM_K = URIRef("http://qudt.org/vocab/unit/CAL_IT-PER-GM-K")
    BIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/BIT-PER-SEC")
    DEG_C_GROWING_CEREAL_DAY = URIRef("http://qudt.org/vocab/unit/DEG_C_GROWING_CEREAL-DAY")
    PINT_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-SEC")
    KiloM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloM-PER-DAY")
    OHM_KiloM = URIRef("http://qudt.org/vocab/unit/OHM-KiloM")
    GM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-M3")
    MicroMOL = URIRef("http://qudt.org/vocab/unit/MicroMOL")
    LB_PER_FT_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-MIN")
    KiloBIT = URIRef("http://qudt.org/vocab/unit/KiloBIT")
    MilliGM_SEC_PER_L2 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L2")
    PERCENT_PER_10KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-10KiloCount")
    KiloPOND = URIRef("http://qudt.org/vocab/unit/KiloPOND")
    MOL_K = URIRef("http://qudt.org/vocab/unit/MOL-K")
    MicroGM_PER_M3_HR = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-M3-HR")
    MI_PER_HR = URIRef("http://qudt.org/vocab/unit/MI-PER-HR")
    MilliW_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM")
    PER_EV_M3 = URIRef("http://qudt.org/vocab/unit/PER-EV-M3")
    BQ_PER_L = URIRef("http://qudt.org/vocab/unit/BQ-PER-L")
    BAR_PER_BAR = URIRef("http://qudt.org/vocab/unit/BAR-PER-BAR")
    EUR_PER_KiloW_HR = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW-HR")
    BTU_TH_PER_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-HR")
    MilliMOL_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3")
    ARE = URIRef("http://qudt.org/vocab/unit/ARE")
    FT_LB_F_PER_SEC = URIRef("http://qudt.org/vocab/unit/FT-LB_F-PER-SEC")
    MegaJ_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-KiloGM")
    DEG_F_PER_BAR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-BAR")
    GigaHZ_M = URIRef("http://qudt.org/vocab/unit/GigaHZ-M")
    MIL_Circ = URIRef("http://qudt.org/vocab/unit/MIL_Circ")
    BARN = URIRef("http://qudt.org/vocab/unit/BARN")
    GM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3")
    PERCENT_PER_IN = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-IN")
    CD_PER_M2 = URIRef("http://qudt.org/vocab/unit/CD-PER-M2")
    MicroMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-L")
    PicoA_PER_HectoPA = URIRef("http://qudt.org/vocab/unit/PicoA-PER-HectoPA")
    IN2 = URIRef("http://qudt.org/vocab/unit/IN2")
    OZ_VOL_US = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US")
    MilliL_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-MIN-K")
    GM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-BAR")
    KiloCD = URIRef("http://qudt.org/vocab/unit/KiloCD")
    M4_PER_SEC = URIRef("http://qudt.org/vocab/unit/M4-PER-SEC")
    TON_Metric_PER_M3_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3-K")
    KiloGM_PER_PA_SEC_M = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA-SEC-M")
    PERCENT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-GAL_UK")
    failures_in_time = URIRef("http://qudt.org/vocab/unit/failures-in-time")
    Hundredweight_UK = URIRef("http://qudt.org/vocab/unit/Hundredweight_UK")
    DEG_F_HR_PER_BTU_IT = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_IT")
    DYN = URIRef("http://qudt.org/vocab/unit/DYN")
    PERCENT_PER_YR = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-YR")
    KiloGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC-BAR")
    MilliGM_PER_K = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-K")
    PERCENT_PER_100KiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-100KiloCount")
    MOL_PER_M3_SEC = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-SEC")
    NanoGM_PER_MicroL = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-MicroL")
    OZ_VOL_US_PER_DAY = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-DAY")
    PERCENT_SEC_PER_YD3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-YD3")
    SON = URIRef("http://qudt.org/vocab/unit/SON")
    M3_PER_K = URIRef("http://qudt.org/vocab/unit/M3-PER-K")
    PetaBIT = URIRef("http://qudt.org/vocab/unit/PetaBIT")
    THM_EEC = URIRef("http://qudt.org/vocab/unit/THM_EEC")
    PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PER-MicroMOL-L")
    M3_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY-BAR")
    CentiL = URIRef("http://qudt.org/vocab/unit/CentiL")
    LA = URIRef("http://qudt.org/vocab/unit/LA")
    KiloM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloM2-PER-SEC2")
    DEGREE_API = URIRef("http://qudt.org/vocab/unit/DEGREE_API")
    IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN3-PER-SEC")
    TON_Metric_PER_HA = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HA")
    KiloGM2_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM2-PER-SEC2")
    GM_PER_CentiM_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM-BAR")
    N_M_PER_ARCMIN = URIRef("http://qudt.org/vocab/unit/N-M-PER-ARCMIN")
    OZ_PER_GAL = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL")
    NanoL = URIRef("http://qudt.org/vocab/unit/NanoL")
    DeciB_Z = URIRef("http://qudt.org/vocab/unit/DeciB_Z")
    MicroCi = URIRef("http://qudt.org/vocab/unit/MicroCi")
    A_Stat = URIRef("http://qudt.org/vocab/unit/A_Stat")
    TeraBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraBIT-PER-SEC")
    BBL_US_PET_PER_HR = URIRef("http://qudt.org/vocab/unit/BBL_US_PET-PER-HR")
    OZ_PER_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-PER-GAL_US")
    CAL_TH_PER_CentiM_SEC_DEG_C = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM-SEC-DEG_C")
    ERG_CentiM2 = URIRef("http://qudt.org/vocab/unit/ERG-CentiM2")
    KAT_PER_MicroL = URIRef("http://qudt.org/vocab/unit/KAT-PER-MicroL")
    KiloN_PER_M = URIRef("http://qudt.org/vocab/unit/KiloN-PER-M")
    MilliGM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-CentiM3")
    PicoA = URIRef("http://qudt.org/vocab/unit/PicoA")
    BIOT = URIRef("http://qudt.org/vocab/unit/BIOT")
    M3_PER_MIN = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN")
    GM_HR_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L-CentiM3")
    V_PER_IN = URIRef("http://qudt.org/vocab/unit/V-PER-IN")
    GM_PER_M3 = URIRef("http://qudt.org/vocab/unit/GM-PER-M3")
    MilliV_PER_M = URIRef("http://qudt.org/vocab/unit/MilliV-PER-M")
    MOL_PER_M3_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-PA")
    BTU_TH_PER_FT2_SEC = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-SEC")
    PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PER-PA-SEC")
    PER_IN2 = URIRef("http://qudt.org/vocab/unit/PER-IN2")
    MilliV = URIRef("http://qudt.org/vocab/unit/MilliV")
    MilliW_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/MilliW-PER-M2-NanoM-SR")
    CentiM3_PER_MOL_SEC = URIRef("http://qudt.org/vocab/unit/CentiM3-PER-MOL-SEC")
    DeciM2 = URIRef("http://qudt.org/vocab/unit/DeciM2")
    LB_F_FT = URIRef("http://qudt.org/vocab/unit/LB_F-FT")
    MilliGM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-M3-L")
    MilliGM_PER_L_MilliPA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-MilliPA-SEC")
    J_PER_MIN = URIRef("http://qudt.org/vocab/unit/J-PER-MIN")
    M_K = URIRef("http://qudt.org/vocab/unit/M-K")
    PER_M_SEC = URIRef("http://qudt.org/vocab/unit/PER-M-SEC")
    PicoA_PER_MicroMOL_L = URIRef("http://qudt.org/vocab/unit/PicoA-PER-MicroMOL-L")
    CentiST = URIRef("http://qudt.org/vocab/unit/CentiST")
    LB_F_PER_IN2_DEG_F = URIRef("http://qudt.org/vocab/unit/LB_F-PER-IN2-DEG_F")
    W_PER_M2_NanoM = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM")
    MilliGAL_PER_MO = URIRef("http://qudt.org/vocab/unit/MilliGAL-PER-MO")
    KiloGM_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-MIN")
    REM_PER_SEC = URIRef("http://qudt.org/vocab/unit/REM-PER-SEC")
    UNKNOWN = URIRef("http://qudt.org/vocab/unit/UNKNOWN")
    LB_MIN_PER_FT3_YD3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-YD3")
    N_M_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/N-M-SEC-PER-M")
    W_PER_M = URIRef("http://qudt.org/vocab/unit/W-PER-M")
    DeciS_PER_M = URIRef("http://qudt.org/vocab/unit/DeciS-PER-M")
    KiloGM_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-SEC2")
    GAL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-MIN")
    OZ_HR_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN6")
    MicroFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/MicroFARAD-PER-M")
    FT_PER_DAY = URIRef("http://qudt.org/vocab/unit/FT-PER-DAY")
    MilliM3 = URIRef("http://qudt.org/vocab/unit/MilliM3")
    GigaJ_PER_M2 = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-M2")
    GibiBIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/GibiBIT-PER-M3")
    MilliL_PER_HR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR")
    ExaV_A = URIRef("http://qudt.org/vocab/unit/ExaV-A")
    GM_SEC_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M3-CentiM3")
    KiloGM_PER_DeciM3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3")
    BIT_PER_M3 = URIRef("http://qudt.org/vocab/unit/BIT-PER-M3")
    KiloHZ_M = URIRef("http://qudt.org/vocab/unit/KiloHZ-M")
    CentiM2 = URIRef("http://qudt.org/vocab/unit/CentiM2")
    NanoFARAD = URIRef("http://qudt.org/vocab/unit/NanoFARAD")
    MilliV_A_PER_K = URIRef("http://qudt.org/vocab/unit/MilliV-A-PER-K")
    GT = URIRef("http://qudt.org/vocab/unit/GT")
    MilliGM_PER_DeciL = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DeciL")
    MicroMOL_PER_GM_SEC = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-GM-SEC")
    PlanckArea = URIRef("http://qudt.org/vocab/unit/PlanckArea")
    ATM_T_PER_M = URIRef("http://qudt.org/vocab/unit/ATM_T-PER-M")
    MilliM3_PER_M3 = URIRef("http://qudt.org/vocab/unit/MilliM3-PER-M3")
    MicroM_PER_L_DAY = URIRef("http://qudt.org/vocab/unit/MicroM-PER-L-DAY")
    PERM_Metric_23DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_23DEG_C")
    M5 = URIRef("http://qudt.org/vocab/unit/M5")
    BTU_TH_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2")
    KiloL_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloL-PER-HR")
    LB_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN6")
    LB_PER_MIN = URIRef("http://qudt.org/vocab/unit/LB-PER-MIN")
    FATH = URIRef("http://qudt.org/vocab/unit/FATH")
    PERCENT_HR_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-M3")
    NanoGRAY_PER_HR = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-HR")
    OZ_VOL_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-MIN")
    NanoGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoGRAY-PER-SEC")
    KiloBTU_IT_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloBTU_IT-PER-HR")
    C_PER_MilliM2 = URIRef("http://qudt.org/vocab/unit/C-PER-MilliM2")
    S_Stat = URIRef("http://qudt.org/vocab/unit/S_Stat")
    BREATH_PER_MIN = URIRef("http://qudt.org/vocab/unit/BREATH-PER-MIN")
    SCF_PER_MIN = URIRef("http://qudt.org/vocab/unit/SCF-PER-MIN")
    BU_US_DRY_PER_DAY = URIRef("http://qudt.org/vocab/unit/BU_US_DRY-PER-DAY")
    KiloCAL_IT_PER_HR_M_DEG_C = URIRef("http://qudt.org/vocab/unit/KiloCAL_IT-PER-HR-M-DEG_C")
    LB_PER_FT_SEC = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-SEC")
    GM_HR_PER_M3_L = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-L")
    LB_T = URIRef("http://qudt.org/vocab/unit/LB_T")
    MegaS_PER_M = URIRef("http://qudt.org/vocab/unit/MegaS-PER-M")
    PetaFLOPS = URIRef("http://qudt.org/vocab/unit/PetaFLOPS")
    M2_PER_HZ_DEG = URIRef("http://qudt.org/vocab/unit/M2-PER-HZ-DEG")
    BBL_US = URIRef("http://qudt.org/vocab/unit/BBL_US")
    DeciN_M = URIRef("http://qudt.org/vocab/unit/DeciN-M")
    BREWSTER = URIRef("http://qudt.org/vocab/unit/BREWSTER")
    MI2 = URIRef("http://qudt.org/vocab/unit/MI2")
    MOMME_Pearl = URIRef("http://qudt.org/vocab/unit/MOMME_Pearl")
    MilliA_PER_LB_F_IN2 = URIRef("http://qudt.org/vocab/unit/MilliA-PER-LB_F-IN2")
    EUR_PER_M2 = URIRef("http://qudt.org/vocab/unit/EUR-PER-M2")
    KAT_PER_M3 = URIRef("http://qudt.org/vocab/unit/KAT-PER-M3")
    OHM_PER_K = URIRef("http://qudt.org/vocab/unit/OHM-PER-K")
    MilliGM_PER_M3_PA_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-PA-SEC")
    MicroV_A_Reactive = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive")
    TONNE_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-SEC-K")
    OZ_MIN_PER_IN6 = URIRef("http://qudt.org/vocab/unit/OZ-MIN-PER-IN6")
    PSI = URIRef("http://qudt.org/vocab/unit/PSI")
    MicroM_PER_M = URIRef("http://qudt.org/vocab/unit/MicroM-PER-M")
    KiloGM_PER_M3 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3")
    S_Ab = URIRef("http://qudt.org/vocab/unit/S_Ab")
    MicroS = URIRef("http://qudt.org/vocab/unit/MicroS")
    GRAIN = URIRef("http://qudt.org/vocab/unit/GRAIN")
    MilliGM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC-BAR")
    MilliMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-MOL")
    PlanckVolume = URIRef("http://qudt.org/vocab/unit/PlanckVolume")
    CD_PER_IN2 = URIRef("http://qudt.org/vocab/unit/CD-PER-IN2")
    PA_M_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/PA-M-PER-SEC2")
    MilliK_PER_K = URIRef("http://qudt.org/vocab/unit/MilliK-PER-K")
    MilliGM_SEC_PER_L_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-L-CentiM3")
    LB_MIN_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-IN3-GAL_UK")
    K_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-PER-SEC")
    BBL_UK_PET_PER_DAY = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET-PER-DAY")
    PERCENT_PER_CentiPOISE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-CentiPOISE")
    ONE_PER_ONE = URIRef("http://qudt.org/vocab/unit/ONE-PER-ONE")
    KiloGM_PER_M_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M-DAY")
    PERCENT_PER_PERCENT = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PERCENT")
    A_PER_K = URIRef("http://qudt.org/vocab/unit/A-PER-K")
    MO_MeanGREGORIAN = URIRef("http://qudt.org/vocab/unit/MO_MeanGREGORIAN")
    MicroM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroM-PER-MilliL")
    BTU_39DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_39DEG_F")
    MilliA_IN2_PER_LB_F = URIRef("http://qudt.org/vocab/unit/MilliA-IN2-PER-LB_F")
    FT_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-DEG_F")
    W_PER_M2_K4 = URIRef("http://qudt.org/vocab/unit/W-PER-M2-K4")
    MilliGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY-BAR")
    GM_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/GM-PER-M2-DAY")
    MilliL_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-BAR")
    KiloGRAY = URIRef("http://qudt.org/vocab/unit/KiloGRAY")
    K_M = URIRef("http://qudt.org/vocab/unit/K-M")
    A_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/A-PER-CentiM2")
    CAL_TH_PER_SEC = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-SEC")
    GM_PER_M3_POISE = URIRef("http://qudt.org/vocab/unit/GM-PER-M3-POISE")
    MilliA = URIRef("http://qudt.org/vocab/unit/MilliA")
    K_SEC = URIRef("http://qudt.org/vocab/unit/K-SEC")
    PA_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-PER-BAR")
    PERCENT_HR_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/PERCENT-HR-PER-CentiM3")
    V_PER_PA = URIRef("http://qudt.org/vocab/unit/V-PER-PA")
    KiloGM_PER_PA = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-PA")
    PicoS_PER_M = URIRef("http://qudt.org/vocab/unit/PicoS-PER-M")
    GM_HR_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-M3-CentiM3")
    LB_PER_IN = URIRef("http://qudt.org/vocab/unit/LB-PER-IN")
    MIN_Sidereal = URIRef("http://qudt.org/vocab/unit/MIN_Sidereal")
    MilliW_PER_MilliGM = URIRef("http://qudt.org/vocab/unit/MilliW-PER-MilliGM")
    GigaJ_PER_HR = URIRef("http://qudt.org/vocab/unit/GigaJ-PER-HR")
    PA_SEC_PER_BAR = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-BAR")
    M3_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-BAR")
    PetaJ = URIRef("http://qudt.org/vocab/unit/PetaJ")
    N_PER_C = URIRef("http://qudt.org/vocab/unit/N-PER-C")
    NanoC = URIRef("http://qudt.org/vocab/unit/NanoC")
    MilliSV_PER_MIN = URIRef("http://qudt.org/vocab/unit/MilliSV-PER-MIN")
    LB_DEG_R = URIRef("http://qudt.org/vocab/unit/LB-DEG_R")
    CASES_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-1000I-YR")
    PER_J2 = URIRef("http://qudt.org/vocab/unit/PER-J2")
    PlanckMass = URIRef("http://qudt.org/vocab/unit/PlanckMass")
    CentiM_H2O = URIRef("http://qudt.org/vocab/unit/CentiM_H2O")
    LB_MIN_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT6")
    MilliGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-DAY")
    GAL_UK = URIRef("http://qudt.org/vocab/unit/GAL_UK")
    BAR_M3_PER_SEC = URIRef("http://qudt.org/vocab/unit/BAR-M3-PER-SEC")
    PER_SR = URIRef("http://qudt.org/vocab/unit/PER-SR")
    LA_FT = URIRef("http://qudt.org/vocab/unit/LA_FT")
    PER_FT3 = URIRef("http://qudt.org/vocab/unit/PER-FT3")
    FT3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/FT3-PER-DEG_F")
    C3_M_PER_J2 = URIRef("http://qudt.org/vocab/unit/C3-M-PER-J2")
    LB_SEC_PER_GAL_UK_FT3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-FT3")
    DEG_C_CentiM = URIRef("http://qudt.org/vocab/unit/DEG_C-CentiM")
    PERCENT_FT_HR_PER_LB = URIRef("http://qudt.org/vocab/unit/PERCENT-FT-HR-PER-LB")
    GAL_US_PER_HR = URIRef("http://qudt.org/vocab/unit/GAL_US-PER-HR")
    L_PER_SEC = URIRef("http://qudt.org/vocab/unit/L-PER-SEC")
    MegaBAR = URIRef("http://qudt.org/vocab/unit/MegaBAR")
    AWG = URIRef("http://qudt.org/vocab/unit/AWG")
    DEG_PER_SEC = URIRef("http://qudt.org/vocab/unit/DEG-PER-SEC")
    M2_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-K")
    M2_PER_J = URIRef("http://qudt.org/vocab/unit/M2-PER-J")
    KiloWB = URIRef("http://qudt.org/vocab/unit/KiloWB")
    CentiM_H2O_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H2O_4DEG_C")
    YD3 = URIRef("http://qudt.org/vocab/unit/YD3")
    TON_LONG_PER_YD3 = URIRef("http://qudt.org/vocab/unit/TON_LONG-PER-YD3")
    IN_H2O_39dot2DEG_F = URIRef("http://qudt.org/vocab/unit/IN_H2O_39dot2DEG_F")
    FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/FT2-DEG_F")
    BTU_IT_PER_FT2_HR_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2-HR-DEG_F")
    BTU_IT_PER_FT2 = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-FT2")
    LB_HR_PER_GAL_UK2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_UK2")
    MicroGM_PER_MilliL = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-MilliL")
    MicroGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/MicroGM-PER-CentiM2")
    HR_Sidereal = URIRef("http://qudt.org/vocab/unit/HR_Sidereal")
    BTU_IT_IN_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN-PER-HR-FT2-DEG_F")
    BARN_PER_SR = URIRef("http://qudt.org/vocab/unit/BARN-PER-SR")
    MilliGM_PER_L_CentiPOISE = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-L-CentiPOISE")
    GigaOHM_PER_M = URIRef("http://qudt.org/vocab/unit/GigaOHM-PER-M")
    BTU_IT_IN = URIRef("http://qudt.org/vocab/unit/BTU_IT-IN")
    HZ_M = URIRef("http://qudt.org/vocab/unit/HZ-M")
    M3_PER_PA = URIRef("http://qudt.org/vocab/unit/M3-PER-PA")
    PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/PER-M2-SEC")
    N_SEC_PER_M2 = URIRef("http://qudt.org/vocab/unit/N-SEC-PER-M2")
    MOL_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-K")
    BTU_IT_PER_HR_FT2_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_IT-PER-HR-FT2-DEG_F")
    DeciB_W = URIRef("http://qudt.org/vocab/unit/DeciB-W")
    W_PER_M_DEG_C = URIRef("http://qudt.org/vocab/unit/W-PER-M-DEG_C")
    DEG_R = URIRef("http://qudt.org/vocab/unit/DEG_R")
    MilliMOL = URIRef("http://qudt.org/vocab/unit/MilliMOL")
    PA_SEC_PER_L = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-L")
    AT = URIRef("http://qudt.org/vocab/unit/AT")
    KiloGM_M = URIRef("http://qudt.org/vocab/unit/KiloGM-M")
    NanoGM_PER_M2_PA_SEC = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-M2-PA-SEC")
    TONNE_PER_M3 = URIRef("http://qudt.org/vocab/unit/TONNE-PER-M3")
    MicroM3 = URIRef("http://qudt.org/vocab/unit/MicroM3")
    MilliGM_PER_KiloGM = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-KiloGM")
    MegaJ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaJ-PER-K")
    KiloP = URIRef("http://qudt.org/vocab/unit/KiloP")
    PER_EV2 = URIRef("http://qudt.org/vocab/unit/PER-EV2")
    DEG_F_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-SEC2")
    PlanckPower = URIRef("http://qudt.org/vocab/unit/PlanckPower")
    PERCENT_PER_HectoKiloCount = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-HectoKiloCount")
    MOL_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB")
    NP_PER_SEC = URIRef("http://qudt.org/vocab/unit/NP-PER-SEC")
    MOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-DAY")
    MegaEV_PER_SpeedOfLight = URIRef("http://qudt.org/vocab/unit/MegaEV-PER-SpeedOfLight")
    TeraJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/TeraJ-PER-SEC")
    CentiM2_PER_GM = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-GM")
    MilliL_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliL-PER-SEC")
    N_M_PER_DEG_M = URIRef("http://qudt.org/vocab/unit/N-M-PER-DEG-M")
    MilliMOL_PER_L = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-L")
    W_PER_M2_M_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-M-SR")
    MilliGM_SEC_PER_M3_L = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M3-L")
    CentiM6 = URIRef("http://qudt.org/vocab/unit/CentiM6")
    PINT_US_PER_MIN = URIRef("http://qudt.org/vocab/unit/PINT_US-PER-MIN")
    CHAIN_US = URIRef("http://qudt.org/vocab/unit/CHAIN_US")
    BTU_TH_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-DEG_F")
    LB_PER_FT_DAY = URIRef("http://qudt.org/vocab/unit/LB-PER-FT-DAY")
    GM_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-BAR")
    GM_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-K")
    YD3_PER_DEG_F = URIRef("http://qudt.org/vocab/unit/YD3-PER-DEG_F")
    PicoMOL = URIRef("http://qudt.org/vocab/unit/PicoMOL")
    BEAT_PER_MIN = URIRef("http://qudt.org/vocab/unit/BEAT-PER-MIN")
    BFT = URIRef("http://qudt.org/vocab/unit/BFT")
    LB_SEC_PER_GAL_US_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_US-IN3")
    STR = URIRef("http://qudt.org/vocab/unit/STR")
    OZ_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-GAL_US")
    DEG_C_WK = URIRef("http://qudt.org/vocab/unit/DEG_C-WK")
    TeraBYTE = URIRef("http://qudt.org/vocab/unit/TeraBYTE")
    DEG_F_HR_PER_BTU_TH = URIRef("http://qudt.org/vocab/unit/DEG_F-HR-PER-BTU_TH")
    KiloLB_F_PER_IN2 = URIRef("http://qudt.org/vocab/unit/KiloLB_F-PER-IN2")
    PicoV_A_Reactive = URIRef("http://qudt.org/vocab/unit/PicoV-A_Reactive")
    CentiGM = URIRef("http://qudt.org/vocab/unit/CentiGM")
    J_PER_DAY = URIRef("http://qudt.org/vocab/unit/J-PER-DAY")
    PERCENT_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEG_C")
    KiloGM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-BAR")
    MilLength = URIRef("http://qudt.org/vocab/unit/MilLength")
    MOL_LB_PER_LB = URIRef("http://qudt.org/vocab/unit/MOL_LB-PER-LB")
    KiloH = URIRef("http://qudt.org/vocab/unit/KiloH")
    MicroMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-M2-DAY")
    TORR_PER_M = URIRef("http://qudt.org/vocab/unit/TORR-PER-M")
    J_SEC_PER_MOL = URIRef("http://qudt.org/vocab/unit/J-SEC-PER-MOL")
    GAL_UK_PER_SEC = URIRef("http://qudt.org/vocab/unit/GAL_UK-PER-SEC")
    MegaFLOPS = URIRef("http://qudt.org/vocab/unit/MegaFLOPS")
    PicoFARAD_PER_M = URIRef("http://qudt.org/vocab/unit/PicoFARAD-PER-M")
    BBL_UK_PET = URIRef("http://qudt.org/vocab/unit/BBL_UK_PET")
    OZ_IN2_PER_IN3_LB_F_SEC = URIRef("http://qudt.org/vocab/unit/OZ-IN2-PER-IN3-LB_F-SEC")
    TONNE_PER_K = URIRef("http://qudt.org/vocab/unit/TONNE-PER-K")
    MIN = URIRef("http://qudt.org/vocab/unit/MIN")
    V_PER_BAR = URIRef("http://qudt.org/vocab/unit/V-PER-BAR")
    EUR_PER_W = URIRef("http://qudt.org/vocab/unit/EUR-PER-W")
    RichterMagnitude = URIRef("http://qudt.org/vocab/unit/RichterMagnitude")
    POISE_PER_PA = URIRef("http://qudt.org/vocab/unit/POISE-PER-PA")
    NanoA = URIRef("http://qudt.org/vocab/unit/NanoA")
    MicroTORR = URIRef("http://qudt.org/vocab/unit/MicroTORR")
    BTU_TH_PER_FT2_HR = URIRef("http://qudt.org/vocab/unit/BTU_TH-PER-FT2-HR")
    MilliGM = URIRef("http://qudt.org/vocab/unit/MilliGM")
    GM_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-L-BAR")
    MOL_PER_KiloGM_PA = URIRef("http://qudt.org/vocab/unit/MOL-PER-KiloGM-PA")
    HP_H2O = URIRef("http://qudt.org/vocab/unit/HP_H2O")
    V_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/V-A_Reactive-PER-K")
    KiloEV_PER_MicroM = URIRef("http://qudt.org/vocab/unit/KiloEV-PER-MicroM")
    MHO_Stat = URIRef("http://qudt.org/vocab/unit/MHO_Stat")
    M2_HZ3 = URIRef("http://qudt.org/vocab/unit/M2-HZ3")
    QT_US_DRY = URIRef("http://qudt.org/vocab/unit/QT_US_DRY")
    NanoV = URIRef("http://qudt.org/vocab/unit/NanoV")
    PT_BIG = URIRef("http://qudt.org/vocab/unit/PT_BIG")
    MicroM_PER_K = URIRef("http://qudt.org/vocab/unit/MicroM-PER-K")
    C_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/C-PER-CentiM3")
    MilliMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M2-DAY")
    MilliBQ_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/MilliBQ-PER-M2-DAY")
    NUM_PER_HA_YR = URIRef("http://qudt.org/vocab/unit/NUM-PER-HA-YR")
    PER_MegaK = URIRef("http://qudt.org/vocab/unit/PER-MegaK")
    NanoGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/NanoGM-PER-DAY")
    KiloGM_PER_CentiM2 = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM2")
    MegaBYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/MegaBYTE-PER-SEC")
    LB_PER_HR = URIRef("http://qudt.org/vocab/unit/LB-PER-HR")
    NanoOHM = URIRef("http://qudt.org/vocab/unit/NanoOHM")
    PERCENT_MIN_PER_FT3 = URIRef("http://qudt.org/vocab/unit/PERCENT-MIN-PER-FT3")
    CLO = URIRef("http://qudt.org/vocab/unit/CLO")
    V_A_Reactive = URIRef("http://qudt.org/vocab/unit/V-A_Reactive")
    M3_PER_DAY = URIRef("http://qudt.org/vocab/unit/M3-PER-DAY")
    BTU_TH = URIRef("http://qudt.org/vocab/unit/BTU_TH")
    LB_SEC_PER_FT6 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT6")
    LB_HR_PER_IN3_FT3 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-FT3")
    SH = URIRef("http://qudt.org/vocab/unit/SH")
    LB_MIN_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_US2")
    IU_PER_MilliL = URIRef("http://qudt.org/vocab/unit/IU-PER-MilliL")
    PA_SEC_PER_M = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-M")
    LB_MIN_PER_FT3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-FT3-GAL_US")
    KiloJ_PER_HR = URIRef("http://qudt.org/vocab/unit/KiloJ-PER-HR")
    NUM_PER_M2 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M2")
    LUX_HR = URIRef("http://qudt.org/vocab/unit/LUX-HR")
    TONNE_PER_HR_BAR = URIRef("http://qudt.org/vocab/unit/TONNE-PER-HR-BAR")
    GM_PER_K = URIRef("http://qudt.org/vocab/unit/GM-PER-K")
    PERCENT_PER_DEGREE = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-DEGREE")
    FT_HR_PER_IN3 = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-IN3")
    J_PER_KiloGM_K = URIRef("http://qudt.org/vocab/unit/J-PER-KiloGM-K")
    NanoMOL_PER_M2_DAY = URIRef("http://qudt.org/vocab/unit/NanoMOL-PER-M2-DAY")
    MOL_PER_L_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-L-BAR")
    ExaBIT_PER_SEC = URIRef("http://qudt.org/vocab/unit/ExaBIT-PER-SEC")
    MilliA_HR_PER_GM = URIRef("http://qudt.org/vocab/unit/MilliA-HR-PER-GM")
    PER_MilliGM = URIRef("http://qudt.org/vocab/unit/PER-MilliGM")
    MilliGM_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-SEC")
    GM_PER_DeciM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DeciM3-K")
    M3_PER_MIN_K = URIRef("http://qudt.org/vocab/unit/M3-PER-MIN-K")
    TebiBIT_PER_M = URIRef("http://qudt.org/vocab/unit/TebiBIT-PER-M")
    PetaJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PetaJ-PER-SEC")
    MilliPA = URIRef("http://qudt.org/vocab/unit/MilliPA")
    TONNE_PER_MO = URIRef("http://qudt.org/vocab/unit/TONNE-PER-MO")
    LB_SEC_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_UK")
    M_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/M-PER-SEC-K")
    MicroATM = URIRef("http://qudt.org/vocab/unit/MicroATM")
    GM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/GM-SEC-PER-M6")
    W_PER_M2_NanoM_SR = URIRef("http://qudt.org/vocab/unit/W-PER-M2-NanoM-SR")
    CP = URIRef("http://qudt.org/vocab/unit/CP")
    M2_PER_SEC_BAR = URIRef("http://qudt.org/vocab/unit/M2-PER-SEC-BAR")
    MilliMOL_PER_M3_DAY = URIRef("http://qudt.org/vocab/unit/MilliMOL-PER-M3-DAY")
    SAMPLE_PER_SEC = URIRef("http://qudt.org/vocab/unit/SAMPLE-PER-SEC")
    KiloV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive-PER-K")
    MilliM_PER_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-M")
    NanoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/NanoJ-PER-SEC")
    FT_PER_SEC_DEG_F = URIRef("http://qudt.org/vocab/unit/FT-PER-SEC-DEG_F")
    PA_SEC_PER_K = URIRef("http://qudt.org/vocab/unit/PA-SEC-PER-K")
    MegaPA = URIRef("http://qudt.org/vocab/unit/MegaPA")
    MilliGM_PER_M2_SEC = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M2-SEC")
    MilliOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/MilliOHM-PER-BAR")
    LB_SEC_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-IN3")
    MilliRAD = URIRef("http://qudt.org/vocab/unit/MilliRAD")
    NanoM_PER_CentiM_PSI = URIRef("http://qudt.org/vocab/unit/NanoM-PER-CentiM-PSI")
    REV_PER_HR = URIRef("http://qudt.org/vocab/unit/REV-PER-HR")
    PERCENT_SEC_PER_IN3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-IN3")
    KiloOHM_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-M")
    PSI_IN3_PER_SEC = URIRef("http://qudt.org/vocab/unit/PSI-IN3-PER-SEC")
    AT_PER_IN = URIRef("http://qudt.org/vocab/unit/AT-PER-IN")
    GM_PER_MIN_BAR = URIRef("http://qudt.org/vocab/unit/GM-PER-MIN-BAR")
    OZ_SEC_PER_IN3_YD3 = URIRef("http://qudt.org/vocab/unit/OZ-SEC-PER-IN3-YD3")
    PERCENT_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/PERCENT-SEC-PER-M3")
    TON_Metric_PER_M3 = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-M3")
    TON_Register = URIRef("http://qudt.org/vocab/unit/TON_Register")
    SLUG_PER_FT2 = URIRef("http://qudt.org/vocab/unit/SLUG-PER-FT2")
    IN = URIRef("http://qudt.org/vocab/unit/IN")
    DeciS = URIRef("http://qudt.org/vocab/unit/DeciS")
    MilliGM_MIN_PER_M3_CentiM3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M3-CentiM3")
    KiloGM_PER_CentiM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-CentiM3-BAR")
    MegaOHM_PER_K = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-K")
    KiloOHM_PER_BAR = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-BAR")
    LB_HR_PER_IN3_GAL_UK = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-IN3-GAL_UK")
    KiloGM_PER_DAY_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY-BAR")
    QUAD = URIRef("http://qudt.org/vocab/unit/QUAD")
    FT_LA = URIRef("http://qudt.org/vocab/unit/FT-LA")
    N_PER_MilliM = URIRef("http://qudt.org/vocab/unit/N-PER-MilliM")
    V_Stat_CentiM = URIRef("http://qudt.org/vocab/unit/V_Stat-CentiM")
    LB_PER_FT2 = URIRef("http://qudt.org/vocab/unit/LB-PER-FT2")
    MilliL_PER_HR_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-HR-K")
    FARAD_PER_KiloM = URIRef("http://qudt.org/vocab/unit/FARAD-PER-KiloM")
    IN2_PER_SEC = URIRef("http://qudt.org/vocab/unit/IN2-PER-SEC")
    MilliJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliJ-PER-SEC")
    FT_HG = URIRef("http://qudt.org/vocab/unit/FT_HG")
    OZ_PER_MIN = URIRef("http://qudt.org/vocab/unit/OZ-PER-MIN")
    MilliGM_HR_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-HR-PER-L-M3")
    MOL_PER_M2_SEC_M_SR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M2-SEC-M-SR")
    OZ_VOL_US_PER_SEC = URIRef("http://qudt.org/vocab/unit/OZ_VOL_US-PER-SEC")
    MegaBIT = URIRef("http://qudt.org/vocab/unit/MegaBIT")
    MI_N_PER_HR = URIRef("http://qudt.org/vocab/unit/MI_N-PER-HR")
    W_M_PER_M2_SR = URIRef("http://qudt.org/vocab/unit/W-M-PER-M2-SR")
    SPF = URIRef("http://qudt.org/vocab/unit/SPF")
    MegaHZ_PER_K = URIRef("http://qudt.org/vocab/unit/MegaHZ-PER-K")
    TON_Metric_PER_HR_K = URIRef("http://qudt.org/vocab/unit/TON_Metric-PER-HR-K")
    PHOT = URIRef("http://qudt.org/vocab/unit/PHOT")
    J_PER_M3_K = URIRef("http://qudt.org/vocab/unit/J-PER-M3-K")
    KiloOHM_PER_M = URIRef("http://qudt.org/vocab/unit/KiloOHM-PER-M")
    MilliGM_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MilliGM-PER-M3-BAR")
    LB_MIN_PER_GAL_UK_IN3 = URIRef("http://qudt.org/vocab/unit/LB-MIN-PER-GAL_UK-IN3")
    FT = URIRef("http://qudt.org/vocab/unit/FT")
    MilliL_PER_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-K")
    MilliM_PER_DEG_C_M = URIRef("http://qudt.org/vocab/unit/MilliM-PER-DEG_C-M")
    MilliA_SEC = URIRef("http://qudt.org/vocab/unit/MilliA-SEC")
    CAL_TH_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/CAL_TH-PER-CentiM3-K")
    FRAME_PER_SEC = URIRef("http://qudt.org/vocab/unit/FRAME-PER-SEC")
    KiloLB_F_FT_PER_LB = URIRef("http://qudt.org/vocab/unit/KiloLB_F-FT-PER-LB")
    GM_PER_SEC_K = URIRef("http://qudt.org/vocab/unit/GM-PER-SEC-K")
    OCTET = URIRef("http://qudt.org/vocab/unit/OCTET")
    MicroMOL_PER_MOL = URIRef("http://qudt.org/vocab/unit/MicroMOL-PER-MOL")
    ONE = URIRef("http://qudt.org/vocab/unit/ONE")
    PER_RAD = URIRef("http://qudt.org/vocab/unit/PER-RAD")
    KiloWB_PER_M = URIRef("http://qudt.org/vocab/unit/KiloWB-PER-M")
    THM_US_PER_HR = URIRef("http://qudt.org/vocab/unit/THM_US-PER-HR")
    MegaOHM_M = URIRef("http://qudt.org/vocab/unit/MegaOHM-M")
    A_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/A-PER-DEG_C")
    NanoMOL = URIRef("http://qudt.org/vocab/unit/NanoMOL")
    FT_PER_PSI = URIRef("http://qudt.org/vocab/unit/FT-PER-PSI")
    REV_PER_MIN = URIRef("http://qudt.org/vocab/unit/REV-PER-MIN")
    OHM_CentiM = URIRef("http://qudt.org/vocab/unit/OHM-CentiM")
    V_PER_CentiM = URIRef("http://qudt.org/vocab/unit/V-PER-CentiM")
    BAUD = URIRef("http://qudt.org/vocab/unit/BAUD")
    SPIN_QUANTUM_NUMBER = URIRef("http://qudt.org/vocab/unit/SPIN_QUANTUM_NUMBER")
    KiloW_PER_M_K = URIRef("http://qudt.org/vocab/unit/KiloW-PER-M-K")
    KiloGM_PER_M3_K = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-M3-K")
    K2 = URIRef("http://qudt.org/vocab/unit/K2")
    MI_US_PER_SEC2 = URIRef("http://qudt.org/vocab/unit/MI_US-PER-SEC2")
    OHM_CIRC_MIL_PER_FT = URIRef("http://qudt.org/vocab/unit/OHM_CIRC-MIL-PER-FT")
    MillionUSD_PER_YR = URIRef("http://qudt.org/vocab/unit/MillionUSD-PER-YR")
    IN_HG_32DEG_F = URIRef("http://qudt.org/vocab/unit/IN_HG_32DEG_F")
    PetaW = URIRef("http://qudt.org/vocab/unit/PetaW")
    LB_DEG_F = URIRef("http://qudt.org/vocab/unit/LB-DEG_F")
    MilliL_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/MilliL-PER-DAY-K")
    BAR_PER_DEG_C = URIRef("http://qudt.org/vocab/unit/BAR-PER-DEG_C")
    LANGLEY = URIRef("http://qudt.org/vocab/unit/LANGLEY")
    OZ_HR_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/OZ-HR-PER-IN3-GAL_US")
    ERG_PER_GM = URIRef("http://qudt.org/vocab/unit/ERG-PER-GM")
    CentiN = URIRef("http://qudt.org/vocab/unit/CentiN")
    PlanckCurrentDensity = URIRef("http://qudt.org/vocab/unit/PlanckCurrentDensity")
    NUM_PER_GM = URIRef("http://qudt.org/vocab/unit/NUM-PER-GM")
    NUM_PER_SEC = URIRef("http://qudt.org/vocab/unit/NUM-PER-SEC")
    KiloMOL_PER_MIN = URIRef("http://qudt.org/vocab/unit/KiloMOL-PER-MIN")
    EUR_PER_KiloW = URIRef("http://qudt.org/vocab/unit/EUR-PER-KiloW")
    FBM = URIRef("http://qudt.org/vocab/unit/FBM")
    TON_UK = URIRef("http://qudt.org/vocab/unit/TON_UK")
    DEG_F_PER_HR = URIRef("http://qudt.org/vocab/unit/DEG_F-PER-HR")
    PERM_Metric_0DEG_C = URIRef("http://qudt.org/vocab/unit/PERM_Metric_0DEG_C")
    FT_HR_PER_GAL_UK = URIRef("http://qudt.org/vocab/unit/FT-HR-PER-GAL_UK")
    GM_HR_PER_L2 = URIRef("http://qudt.org/vocab/unit/GM-HR-PER-L2")
    DYN_SEC_PER_CentiM5 = URIRef("http://qudt.org/vocab/unit/DYN-SEC-PER-CentiM5")
    MilliGM_MIN_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-M6")
    FUR_Long = URIRef("http://qudt.org/vocab/unit/FUR_Long")
    NanoOHM_M = URIRef("http://qudt.org/vocab/unit/NanoOHM-M")
    PPM_PER_K = URIRef("http://qudt.org/vocab/unit/PPM-PER-K")
    PERCENT_PER_OHM = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-OHM")
    BQ_SEC_PER_M3 = URIRef("http://qudt.org/vocab/unit/BQ-SEC-PER-M3")
    LB_HR_PER_GAL_US2 = URIRef("http://qudt.org/vocab/unit/LB-HR-PER-GAL_US2")
    KiloGM_PER_DeciM3_BAR = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DeciM3-BAR")
    ERG_SEC = URIRef("http://qudt.org/vocab/unit/ERG-SEC")
    KiloGM_PER_KiloMOL = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-KiloMOL")
    CentiM_H20_4DEG_C = URIRef("http://qudt.org/vocab/unit/CentiM_H20_4DEG_C")
    MilliARCSEC = URIRef("http://qudt.org/vocab/unit/MilliARCSEC")
    GM_PER_CentiM3_K = URIRef("http://qudt.org/vocab/unit/GM-PER-CentiM3-K")
    NanoM = URIRef("http://qudt.org/vocab/unit/NanoM")
    MegaGRAY = URIRef("http://qudt.org/vocab/unit/MegaGRAY")
    W_PER_M2_PA = URIRef("http://qudt.org/vocab/unit/W-PER-M2-PA")
    NUM_PER_PicoL = URIRef("http://qudt.org/vocab/unit/NUM-PER-PicoL")
    MegaV_A_HR = URIRef("http://qudt.org/vocab/unit/MegaV-A-HR")
    TeraBIT = URIRef("http://qudt.org/vocab/unit/TeraBIT")
    M2_K = URIRef("http://qudt.org/vocab/unit/M2-K")
    PDL_SEC_PER_IN2 = URIRef("http://qudt.org/vocab/unit/PDL-SEC-PER-IN2")
    CD_IN = URIRef("http://qudt.org/vocab/unit/CD_IN")
    Stone_UK = URIRef("http://qudt.org/vocab/unit/Stone_UK")
    LB_SEC_PER_IN3_GAL_US = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-IN3-GAL_US")
    PicoJ_PER_SEC = URIRef("http://qudt.org/vocab/unit/PicoJ-PER-SEC")
    PDL_FT = URIRef("http://qudt.org/vocab/unit/PDL-FT")
    PERCENT_PER_PA_SEC = URIRef("http://qudt.org/vocab/unit/PERCENT-PER-PA-SEC")
    MicroV_A_Reactive_PER_K = URIRef("http://qudt.org/vocab/unit/MicroV-A_Reactive-PER-K")
    CentiM2_PER_CentiM3 = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-CentiM3")
    KiloGM_PER_DAY = URIRef("http://qudt.org/vocab/unit/KiloGM-PER-DAY")
    MOL_PER_M3_BAR = URIRef("http://qudt.org/vocab/unit/MOL-PER-M3-BAR")
    MegaOHM_PER_KiloM = URIRef("http://qudt.org/vocab/unit/MegaOHM-PER-KiloM")
    CentiMOL_PER_L = URIRef("http://qudt.org/vocab/unit/CentiMOL-PER-L")
    TOE = URIRef("http://qudt.org/vocab/unit/TOE")
    GRAY_PER_MIN = URIRef("http://qudt.org/vocab/unit/GRAY-PER-MIN")
    LB_FT_PER_SEC = URIRef("http://qudt.org/vocab/unit/LB-FT-PER-SEC")
    LB_SEC_PER_GAL_UK_YD3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-GAL_UK-YD3")
    MicroG = URIRef("http://qudt.org/vocab/unit/MicroG")
    KiloV_A_Reactive = URIRef("http://qudt.org/vocab/unit/KiloV-A_Reactive")
    CentiM2_PER_SR_ERG = URIRef("http://qudt.org/vocab/unit/CentiM2-PER-SR-ERG")
    AT_PER_M = URIRef("http://qudt.org/vocab/unit/AT-PER-M")
    ENZ_PER_L = URIRef("http://qudt.org/vocab/unit/ENZ-PER-L")
    MilliGRAY_PER_SEC = URIRef("http://qudt.org/vocab/unit/MilliGRAY-PER-SEC")
    K_PER_HR = URIRef("http://qudt.org/vocab/unit/K-PER-HR")
    NUM_PER_M3 = URIRef("http://qudt.org/vocab/unit/NUM-PER-M3")
    GM_PER_DAY_K = URIRef("http://qudt.org/vocab/unit/GM-PER-DAY-K")
    DEGREE_OECHSLE = URIRef("http://qudt.org/vocab/unit/DEGREE_OECHSLE")
    BYTE_PER_SEC = URIRef("http://qudt.org/vocab/unit/BYTE-PER-SEC")
    LB_SEC_PER_FT3_IN3 = URIRef("http://qudt.org/vocab/unit/LB-SEC-PER-FT3-IN3")
    MilliGM_MIN_PER_L_M3 = URIRef("http://qudt.org/vocab/unit/MilliGM-MIN-PER-L-M3")
    CASES_PER_KiloINDIV_YR = URIRef("http://qudt.org/vocab/unit/CASES-PER-KiloINDIV-YR")
    DEATHS_PER_1000I_YR = URIRef("http://qudt.org/vocab/unit/DEATHS-PER-1000I-YR")
    K_M_PER_SEC = URIRef("http://qudt.org/vocab/unit/K-M-PER-SEC")
    PlanckCurrent = URIRef("http://qudt.org/vocab/unit/PlanckCurrent")
    MilliGM_SEC_PER_M6 = URIRef("http://qudt.org/vocab/unit/MilliGM-SEC-PER-M6")
    K_DAY = URIRef("http://qudt.org/vocab/unit/K-DAY")
    KiloMIL_Circ = URIRef("http://qudt.org/vocab/unit/KiloMIL_Circ")

    _NS = Namespace("http://qudt.org/vocab/unit/")